@@ -1,21 +1,27 @@
-# Copyright 2021 Q-CTRL. All rights reserved.
+# Copyright 2022 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
 # Proprietary and confidential. You may not use this file except in compliance
 # with the License. You may obtain a copy of the License at
 #
-#      https://q-ctrl.com/terms
+#    https://q-ctrl.com/terms
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
-"""Module for declaring the datatype."""
+"""
+Module for declaring the datatype.
+"""
 import base64
 from typing import Any
 
 import numpy as np
-from scipy.sparse import coo_matrix
+from scipy.sparse import (
+    coo_matrix,
+    dok_matrix,
+    spmatrix,
+)
 
 from qctrlcommons.graph import Graph
 from qctrlcommons.node.registry import (
@@ -28,6 +34,26 @@ from qctrlcommons.node.wrapper import (
 )
 
 
+def handle_built_in_iterator(obj):
+    """
+    Handles the object that inherits from the built-in list/dict, but can't be encoded, or
+    needs to be encoded in other format.
+
+    DOK(Dictionary Of Keys based sparse matrix): not supported as key is a tuple.
+    """
+
+    if isinstance(obj, dok_matrix):
+        return SparseMatrix().encode(obj)
+    if isinstance(obj, (list, tuple)):
+        return [handle_built_in_iterator(e) for e in obj]
+    if isinstance(obj, dict):
+        return {
+            handle_built_in_iterator(k): handle_built_in_iterator(v)
+            for k, v in obj.items()
+        }
+    return obj
+
+
 class DataType:
     """Framework for supporting data types which are not JSON serializable by
     default.
@@ -63,7 +89,7 @@ class DataType:
             if the data type is `None`.
         """
         if self._type is None:
-            raise RuntimeError("_type not set for: {}".format(self))
+            raise RuntimeError(f"_type not set for: {self}")
 
         return isinstance(  # pylint:disable=isinstance-second-argument-not-valid-type
             obj, self._type
@@ -100,7 +126,7 @@ class DataType:
             if `object_key` is `None`.
         """
         if self.object_key is None:
-            raise RuntimeError("object_key not set for: {}".format(self))
+            raise RuntimeError(f"object_key not set for: {self}")
 
         return self.object_key in obj
 
@@ -141,9 +167,7 @@ class EllipsisDataType(DataType):
     object_key = "encoded_ellipsis"
 
     def encode(self, obj) -> dict:
-        return {
-            self.object_key: True,
-        }
+        return {self.object_key: True}
 
     def decode(self, obj: dict):
         return ...
@@ -253,18 +277,19 @@ class NumpyComplexNumber(DataType):
 class SparseMatrix(DataType):
     """Represent SparseMatrix Model."""
 
-    _type = coo_matrix
+    _type = spmatrix
     object_key = "encoded_coo_matrix"
 
     def encode(self, obj) -> dict:
+        coo_obj = obj.tocoo()
         return {
             self.object_key: {
-                "data": obj.data,
-                "row": obj.row,
-                "col": obj.col,
+                "data": coo_obj.data,
+                "row": coo_obj.row,
+                "col": coo_obj.col,
             },
-            "dtype": str(obj.dtype),
-            "shape": list(obj.shape),
+            "dtype": str(coo_obj.dtype),
+            "shape": list(coo_obj.shape),
         }
 
     def decode(self, obj: dict) -> coo_matrix:
@@ -350,6 +375,8 @@ class GraphDataType(DataType):
         return {
             self.object_key: True,
             "operations": obj.operations,
+            # Continue sending old parameter for backwards compatibility.
+            "dependencies": {},
         }
 
     def decode(self, obj: dict) -> Graph:
@@ -396,6 +423,7 @@ class OperationDataType(DataType):
         Checks which kwargs contain values that represent
         NodeData and stores only the references for those values.
         """
+
         if isinstance(value, NodeData):
             return {"_kwarg_type": "node", "value": value.operation.name}
 
@@ -405,7 +433,7 @@ class OperationDataType(DataType):
         if isinstance(value, list):
             return [self._set_kwargs_reference(input) for input in value]
 
-        if isinstance(value, dict):
+        if isinstance(value, dict) and not isinstance(value, dok_matrix):
             return {key: self._set_kwargs_reference(value[key]) for key in value}
 
         return value
@@ -429,7 +457,7 @@ class OperationDataType(DataType):
             self.object_key: True,
             "id": obj_id,
             "operation_name": operation_name,
-            "kwargs": kwargs,
+            "kwargs": handle_built_in_iterator(kwargs),
         }
 
     def decode(self, obj: dict):
@@ -451,10 +479,7 @@ class FloatConstant(DataType):
         return super().can_encode(obj) and str(obj) in self._constants
 
     def encode(self, obj) -> dict:
-        return {
-            self.object_key: True,
-            "value": str(obj),
-        }
+        return {self.object_key: True, "value": str(obj)}
 
     def can_decode(self, obj: dict) -> bool:
         return super().can_decode(obj) and obj["value"] in self._constants
@@ -481,4 +506,4 @@ class FloatConstant(DataType):
         if obj == "NaN":
             return self.encode(float("nan"))
 
-        return ValueError("%s is not a valid json float constant" % obj)
+        return ValueError(f"{obj} is not a valid json float constant")
