@@ -31,6 +31,7 @@ from qctrlcommons.node.utils import (
     NumericOrFunction,
     TensorLikeOrFunction,
     get_broadcasted_shape,
+    mesh_pwc_durations,
     validate_batch_and_value_shapes,
     validate_broadcasted_shape,
     validate_function_output_shapes,
@@ -122,20 +123,11 @@ def _create_flexible_binary_node_data(
             validate_value_shape=validate_value_shape,
         )
 
-        upsampled_durations = np.diff(
-            np.insert(
-                np.unique(
-                    np.concatenate([np.cumsum(x.durations), np.cumsum(y.durations)])
-                ),
-                0,
-                0,
-            )
-        )
-
+        durations = mesh_pwc_durations([x, y])
         return Pwc(
             _operation,
             value_shape=value_shape,
-            durations=upsampled_durations,
+            durations=durations,
             batch_shape=batch_shape,
         )
 
@@ -221,7 +213,7 @@ def _create_flexible_binary_node_data(
 
 class Addition(Node):
     """
-    Calculates the element-wise sum between numbers, np.ndarrays, Tensors, Pwcs,
+    Calculate the element-wise sum between numbers, np.ndarrays, Tensors, Pwcs,
     or Stfs. You can also use the arithmetic operator ``+`` to calculate their sum.
 
     Considering numbers and np.ndarrays as Tensors, if the two objects are of the same type,
@@ -261,7 +253,7 @@ class Addition(Node):
 
 class Subtraction(Node):
     """
-    Calculates the element-wise difference between numbers, np.ndarrays, Tensors, Pwcs,
+    Calculate the element-wise difference between numbers, np.ndarrays, Tensors, Pwcs,
     or Stfs. You can also use the arithmetic operator ``-`` to calculate their difference.
 
     Considering numbers and np.ndarrays as Tensors, if the two objects are of the same type,
@@ -301,7 +293,7 @@ class Subtraction(Node):
 
 class Multiplication(Node):
     r"""
-    Calculates the element-wise product between numbers, np.ndarrays, Tensors,
+    Calculate the element-wise product between numbers, np.ndarrays, Tensors,
     Pwcs, or Stfs. You can also use the arithmetic operator ``*`` to calculate their product.
 
     Considering numbers and np.ndarrays as Tensors, if the two objects are of the same type,
@@ -341,7 +333,7 @@ class Multiplication(Node):
 
 class TrueDivision(Node):
     """
-    Calculates the element-wise division between numbers, np.ndarrays, Tensors, Pwcs,
+    Calculate the element-wise division between numbers, np.ndarrays, Tensors, Pwcs,
     or Stfs. You can also use the arithmetic operator ``/`` to calculate their division.
 
     Considering numbers and np.ndarrays as Tensors, if the two objects are of the same type,
@@ -385,7 +377,7 @@ class TrueDivision(Node):
 
 class FloorDivision(Node):
     r"""
-    Calculates the element-wise rounded-down division between real numbers, np.ndarrays, Tensors,
+    Calculate the element-wise rounded-down division between real numbers, np.ndarrays, Tensors,
     Pwcs, or Stfs. You can also use the arithmetic operator ``//`` to calculate their floor
     division.
 
@@ -430,7 +422,7 @@ class FloorDivision(Node):
 
 class Exponentiation(Node):
     """
-    Calculates the element-wise power between numbers, np.ndarrays, Tensors, Pwcs,
+    Calculate the element-wise power between numbers, np.ndarrays, Tensors, Pwcs,
     or Stfs. You can also use the arithmetic operator ``**`` to calculate their power.
 
     Considering numbers and np.ndarrays as Tensors, if the two objects are of the same type,
@@ -476,7 +468,7 @@ class Exponentiation(Node):
 
 class ComplexValue(Node):
     """
-    Creates element-wise complex values from real numbers, np.ndarrays, Tensors,
+    Create element-wise complex values from real numbers, np.ndarrays, Tensors,
     Pwcs, or Stfs, that is, the real and imaginary parts.
 
     Considering numbers and np.ndarrays as Tensors, if the two objects are of the same type,
@@ -524,7 +516,7 @@ class ComplexValue(Node):
 
 class Matmul(Node):
     """
-    Calculates the matrix multiplication between np.ndarrays, Tensors,
+    Calculate the matrix multiplication between np.ndarrays, Tensors,
     Pwcs, or Stfs. You can also use the arithmetic operator ``@``
     to calculate their matrix multiplication.
 
@@ -610,7 +602,7 @@ class Matmul(Node):
 
 class Kron(Node):
     """
-    Calculates the Kronecker product between np.ndarrays, Tensors,
+    Calculate the Kronecker product between np.ndarrays, Tensors,
     Pwcs, or Stfs.
 
     If any of the inputs is a Pwc or Stf, the output is also a
