@@ -64,8 +64,10 @@ def _create_flexible_unary_node_data(_operation, x, name, value_shape_changer=No
     """
 
     # By default don't change shapes.
-    if value_shape_changer is None:
-        value_shape_changer = lambda shape: shape
+    def get_value_shape(shape):
+        if value_shape_changer is None:
+            return shape
+        return value_shape_changer(shape)
 
     if isinstance(x, Stf):
         check_argument(
@@ -74,7 +76,7 @@ def _create_flexible_unary_node_data(_operation, x, name, value_shape_changer=No
         batch_shape, value_shape = validate_batch_and_value_shapes(x, "x")
         return Stf(
             _operation,
-            value_shape=value_shape_changer(value_shape),
+            value_shape=get_value_shape(value_shape),
             batch_shape=batch_shape,
         )
 
@@ -82,19 +84,19 @@ def _create_flexible_unary_node_data(_operation, x, name, value_shape_changer=No
         batch_shape, value_shape = validate_batch_and_value_shapes(x, "x")
         return Pwc(
             _operation,
-            value_shape=value_shape_changer(value_shape),
+            value_shape=get_value_shape(value_shape),
             durations=x.durations,
             batch_shape=batch_shape,
         )
 
     check_argument_numeric(x, "x")
     shape = validate_shape(x, "x")
-    return Tensor(_operation, shape=value_shape_changer(shape))
+    return Tensor(_operation, shape=get_value_shape(shape))
 
 
 class Sqrt(Node):
     r"""
-    Calculates the element-wise square root of an object. This can be a number, an array, a tensor,
+    Calculate the element-wise square root of an object. This can be a number, an array, a tensor,
     or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -127,7 +129,7 @@ class Sqrt(Node):
 
 class Sin(Node):
     r"""
-    Calculates the element-wise sine of an object. This can be a number, an array, a tensor,
+    Calculate the element-wise sine of an object. This can be a number, an array, a tensor,
     or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -146,6 +148,11 @@ class Sin(Node):
         The element-wise sine, :math:`\sin{x}`, of the values or function you provided.
         The returned object is of the same kind as the one you provided, except if you provide a
         number or an np.ndarray in which case it's a Tensor.
+
+    See Also
+    --------
+    :func:`.pulses.sinusoid_pwc` : Creates a `Pwc` representing a sinusoidal oscillation.
+    :func:`.pulses.sinusoid_stf` : Creates an `Stf` representing a sinusoidal oscillation.
     """
 
     name = "sin"
@@ -160,7 +167,7 @@ class Sin(Node):
 
 class Cos(Node):
     r"""
-    Calculates the element-wise cosine of an object. This can be a number, an array, a tensor,
+    Calculate the element-wise cosine of an object. This can be a number, an array, a tensor,
     or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -179,6 +186,12 @@ class Cos(Node):
         The element-wise cosine, :math:`\cos{x}`, of the values or function you provided.
         The returned object is of the same kind as the one you provided, except if you provide a
         number or an np.ndarray in which case it's a Tensor.
+
+    See Also
+    --------
+    :func:`.pulses.cosine_pulse_pwc` : Creates a `Pwc` representing a cosine pulse.
+    :func:`.pulses.sinusoid_pwc` : Creates a `Pwc` representing a sinusoidal oscillation.
+    :func:`.pulses.sinusoid_stf` : Creates an `Stf` representing a sinusoidal oscillation.
     """
 
     name = "cos"
@@ -193,7 +206,7 @@ class Cos(Node):
 
 class Tan(Node):
     r"""
-    Calculates the element-wise tangent of an object. This can be a number, an array, a tensor,
+    Calculate the element-wise tangent of an object. This can be a number, an array, a tensor,
     or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -226,7 +239,7 @@ class Tan(Node):
 
 class Sinh(Node):
     r"""
-    Calculates the element-wise hyperbolic sine of an object. This can be a number, an array,
+    Calculate the element-wise hyperbolic sine of an object. This can be a number, an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -259,7 +272,7 @@ class Sinh(Node):
 
 class Cosh(Node):
     r"""
-    Calculates the element-wise hyperbolic cosine of an object. This can be a number, an array,
+    Calculate the element-wise hyperbolic cosine of an object. This can be a number, an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -292,7 +305,7 @@ class Cosh(Node):
 
 class Tanh(Node):
     r"""
-    Calculates the element-wise hyperbolic tangent of an object. This can be a number, an array,
+    Calculate the element-wise hyperbolic tangent of an object. This can be a number, an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -311,6 +324,11 @@ class Tanh(Node):
         The element-wise hyperbolic tangent, :math:`\tanh{x}`, of the values or function you
         provided. The returned object is of the same kind as the one you provided, except if you
         provide a number or an np.ndarray in which case it's a Tensor.
+
+    See Also
+    --------
+    :func:`.pulses.tanh_ramp_pwc` : Creates a `Pwc` representing a hyperbolic tangent ramp.
+    :func:`.pulses.tanh_ramp_stf` : Creates an `Stf` representing a hyperbolic tangent ramp.
     """
 
     name = "tanh"
@@ -325,7 +343,7 @@ class Tanh(Node):
 
 class Log(Node):
     r"""
-    Calculates the element-wise natural logarithm of an object. This can be a number, an array,
+    Calculate the element-wise natural logarithm of an object. This can be a number, an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -358,7 +376,7 @@ class Log(Node):
 
 class Exp(Node):
     r"""
-    Calculates the element-wise exponential of an object. This can be a number, an array,
+    Calculate the element-wise exponential of an object. This can be a number, an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -391,7 +409,7 @@ class Exp(Node):
 
 class Negative(Node):
     r"""
-    Calculates the element-wise numerical negative value of an object. This can be a number,
+    Calculate the element-wise numerical negative value of an object. This can be a number,
     an array, a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -424,7 +442,7 @@ class Negative(Node):
 
 class Real(Node):
     r"""
-    Calculates the element-wise real part of an object. This can be a number, an array,
+    Calculate the element-wise real part of an object. This can be a number, an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -462,7 +480,7 @@ class Real(Node):
 
 class Imag(Node):
     r"""
-    Calculates the element-wise imaginary part of an object. This can be a number, an array,
+    Calculate the element-wise imaginary part of an object. This can be a number, an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -500,7 +518,7 @@ class Imag(Node):
 
 class Absolute(Node):
     r"""
-    Calculates the element-wise absolute value of an object. This can be a number, an array,
+    Calculate the element-wise absolute value of an object. This can be a number, an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -538,7 +556,7 @@ class Absolute(Node):
 
 class Angle(Node):
     r"""
-    Calculates the element-wise argument of an object. This can be a number, an array,
+    Calculate the element-wise argument of an object. This can be a number, an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -576,7 +594,7 @@ class Angle(Node):
 
 class Conjugate(Node):
     r"""
-    Calculates the element-wise complex conjugate of an object. This can be a number, an array,
+    Calculate the element-wise complex conjugate of an object. This can be a number, an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -613,7 +631,7 @@ class Conjugate(Node):
 
 class Arcsin(Node):
     r"""
-    Calculates the element-wise arcsine of an object. This can be a number, an array,
+    Calculate the element-wise arcsine of an object. This can be a number, an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -647,7 +665,7 @@ class Arcsin(Node):
 
 class Arccos(Node):
     r"""
-    Calculates the element-wise arccosine of an object. This can be a number, an array,
+    Calculate the element-wise arccosine of an object. This can be a number, an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -681,7 +699,7 @@ class Arccos(Node):
 
 class Arctan(Node):
     r"""
-    Calculates the element-wise arctangent of an object. This can be a number, an array,
+    Calculate the element-wise arctangent of an object. This can be a number, an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf.
 
     Parameters
@@ -715,7 +733,7 @@ class Arctan(Node):
 
 class Adjoint(Node):
     r"""
-    Calculates the element-wise adjoint of the last two dimensions of an object.
+    Calculate the element-wise adjoint of the last two dimensions of an object.
     This can be a an array, a tensor, or a time-dependent function in the form of a
     Pwc or an Stf where values have at least two dimensions.
 
@@ -768,7 +786,7 @@ class Adjoint(Node):
 
 class Trace(Node):
     r"""
-    Calculates the trace of an object. This can be a an array,
+    Calculate the trace of an object. This can be a an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf
     where values have at least two dimensions.
     The trace is calculated on the last two dimensions.
@@ -819,7 +837,7 @@ class Trace(Node):
 
 class HermitianPart(Node):
     r"""
-    Calculates the Hermitian part of an object. This can be an array,
+    Calculate the Hermitian part of an object. This can be an array,
     a tensor, or a time-dependent function in the form of a Pwc or an Stf
     where values have at least two dimensions.
     The operation is applied on the last two dimensions, which must be equal to each other.
