@@ -66,7 +66,7 @@ class Node:
     @classmethod
     def create_node_data(cls, _operation, **kwargs):  # pylint:disable=unused-argument
         """
-        Creates the `NodeData` (or sub-class thereof, as determined by the `rtype`) to be returned
+        Create the `NodeData` (or sub-class thereof, as determined by the `rtype`) to be returned
         as the node value.
 
         Can optionally perform validation of the inputs (which themselves will be `NodeData`
@@ -78,7 +78,7 @@ class Node:
     @classmethod
     def create_graph_method(cls):
         """
-        Creates a callable that can be attached as a method to the Graph class for creating nodes of
+        Create a callable that can be attached as a method to the Graph class for creating nodes of
         this type.
         """
 
