@@ -36,7 +36,7 @@ from qctrlcommons.node.utils import (
 
 class FockState(Node):
     r"""
-    Creates a Fock state (or a batch of them).
+    Create a Fock state (or a batch of them).
 
     You can create a Fock state for a single system by providing the `dimension` of the
     truncated Fock space, the occupied energy `level`, and the lowest represented level
@@ -81,14 +81,13 @@ class FockState(Node):
 
     See Also
     --------
-    annihilation_operator : Generates an annihilation operator in the truncated Fock space.
-    coherent_state : Creates a coherent state (or a batch of them).
-    creation_operator : Generates a creation operator in the truncated Fock space.
-    number_operator : Generates a number operator in the truncated Fock space.
+    annihilation_operator : Create an annihilation operator in the truncated Fock space.
+    coherent_state : Create a coherent state (or a batch of them).
+    creation_operator : Create a creation operator in the truncated Fock space.
+    number_operator : Create a number operator in the truncated Fock space.
 
     Examples
     --------
-
     Create a Fock state for a single system.
 
     >>> graph.fock_state(2, 0, name="direct")
@@ -167,7 +166,7 @@ class FockState(Node):
 
 class CreationOperator(Node):
     r"""
-    Generates a creation operator in the truncated Fock space.
+    Create a creation operator in the truncated Fock space.
 
     Parameters
     ----------
@@ -187,14 +186,13 @@ class CreationOperator(Node):
 
     See Also
     --------
-    annihilation_operator : Generates an annihilation operator in the truncated Fock space.
-    coherent_state : Creates a coherent state (or a batch of them).
-    fock_state : Creates a Fock state (or a batch of them).
-    number_operator : Generates a number operator in the truncated Fock space.
+    annihilation_operator : Create an annihilation operator in the truncated Fock space.
+    coherent_state : Create a coherent state (or a batch of them).
+    fock_state : Create a Fock state (or a batch of them).
+    number_operator : Create a number operator in the truncated Fock space.
 
     Examples
     --------
-
     Generate a creation operator for a two-level system.
 
     >>> graph.creation_operator(2, name="adagger")
@@ -259,7 +257,7 @@ class CreationOperator(Node):
 
 class AnnihilationOperator(Node):
     r"""
-    Generates an annihilation operator in the truncated Fock space.
+    Create an annihilation operator in the truncated Fock space.
 
     Parameters
     ----------
@@ -279,14 +277,13 @@ class AnnihilationOperator(Node):
 
     See Also
     --------
-    coherent_state : Creates a coherent state (or a batch of them).
-    creation_operator : Generates a creation operator in the truncated Fock space.
-    fock_state : Creates a Fock state (or a batch of them).
-    number_operator : Generates a number operator in the truncated Fock space.
+    coherent_state : Create a coherent state (or a batch of them).
+    creation_operator : Create a creation operator in the truncated Fock space.
+    fock_state : Create a Fock state (or a batch of them).
+    number_operator : Create a number operator in the truncated Fock space.
 
     Examples
     --------
-
     Generate an annihilation operator for a two-level system.
 
     >>> graph.annihilation_operator(2, name="a")
@@ -352,7 +349,7 @@ class AnnihilationOperator(Node):
 
 class NumberOperator(Node):
     r"""
-    Generates a number operator in the truncated Fock space.
+    Create a number operator in the truncated Fock space.
 
     Parameters
     ----------
@@ -372,14 +369,13 @@ class NumberOperator(Node):
 
     See Also
     --------
-    annihilation_operator : Generates an annihilation operator in the truncated Fock space.
-    coherent_state : Creates a coherent state (or a batch of them).
-    creation_operator : Generates a creation operator in the truncated Fock space.
-    fock_state : Creates a Fock state (or a batch of them).
+    annihilation_operator : Create an annihilation operator in the truncated Fock space.
+    coherent_state : Create a coherent state (or a batch of them).
+    creation_operator : Create a creation operator in the truncated Fock space.
+    fock_state : Create a Fock state (or a batch of them).
 
     Examples
     --------
-
     Generate a number operator for a three-level system.
 
     >>> graph.number_operator(3, name="n")
@@ -447,7 +443,7 @@ class NumberOperator(Node):
 
 class CoherentState(Node):
     r"""
-    Creates a coherent state (or a batch of them).
+    Create a coherent state (or a batch of them).
 
     By default, this function generates the coherent state by applying the displacement operator
     on the vacuum state in the truncated Fock space. Alternatively, you can also generate the
@@ -482,10 +478,10 @@ class CoherentState(Node):
 
     See Also
     --------
-    annihilation_operator : Generates an annihilation operator in the truncated Fock space.
-    creation_operator : Generates a creation operator in the truncated Fock space.
-    fock_state : Creates a Fock state (or a batch of them).
-    number_operator : Generates a number operator in the truncated Fock space.
+    annihilation_operator : Create an annihilation operator in the truncated Fock space.
+    creation_operator : Create a creation operator in the truncated Fock space.
+    fock_state : Create a Fock state (or a batch of them).
+    number_operator : Create a number operator in the truncated Fock space.
 
     Notes
     -----
@@ -494,7 +490,7 @@ class CoherentState(Node):
 
     .. math::
         |\alpha\rangle = D(\alpha)|0\rangle
-                       = \exp(\alpha \hat{a}^\dagger  - \alpha^\ast \hat{a}) | 0 \rangle \;.
+                       = \exp(\alpha \hat{a}^\dagger  - \alpha^\ast \hat{a}) | 0 \rangle .
 
     where :math:`\hat{a}` and :math:`\hat{a}^\dagger` are the annihilation and creation operators
     respectively.
@@ -503,7 +499,7 @@ class CoherentState(Node):
 
     .. math::
         |\alpha\rangle = e^{-\frac{|\alpha|^2}{2}}
-                         \sum_{n=0}^{\infty} \frac{\alpha^n}{\sqrt{n!}}|n\rangle \;.
+                         \sum_{n=0}^{\infty} \frac{\alpha^n}{\sqrt{n!}}|n\rangle .
 
     For more information about coherent states, see `coherent state`_ on Wikipedia.
 
@@ -512,7 +508,6 @@ class CoherentState(Node):
 
     Examples
     --------
-
     Create a coherent state from displacement.
 
     >>> graph.coherent_state(1j, 2, name="state")
