@@ -10,7 +10,7 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
-"""Module for all the node related to MS."""
+"""Module for all the Mølmer–Sørensen related nodes."""
 from typing import (
     List,
     Optional,
@@ -34,13 +34,13 @@ from qctrlcommons.preconditions import (
     check_argument,
     check_argument_iterable,
     check_argument_numeric,
-    check_sample_times,
+    check_sample_times_with_bounds,
 )
 
 
 class MsPhases(Node):
     r"""
-    Calculates the relative phases for all pairs of ions described by a Mølmer–Sørensen-type
+    Calculate the relative phases for all pairs of ions described by a Mølmer–Sørensen-type
     interaction when single-tone individually-addressed laser beams are used.
 
     Use this function to calculate the acquired phases for all ion pairs
@@ -66,10 +66,10 @@ class MsPhases(Node):
         Its shape must be ``(3, N)`` where the first dimension :math:`j` indicates the axis and the
         second dimension :math:`k` indicates the collective mode number.
     sample_times : np.ndarray, optional
-         A 1D array of length :math:`T` specifying the times :math:`\{t_i\}` (in seconds) at which
-         this function calculates the relative phases.
-         If you omit it, this function calculates the phases only at the final time of the drives.
-         If provided, it must be ordered and contain at least one element.
+        A 1D array of length :math:`T` specifying the times :math:`\{t_i\}` (in seconds) at which
+        this function calculates the relative phases.
+        If you omit it, this function calculates the phases only at the final time of the drives.
+        If provided, it must be ordered and contain at least one element.
     name : str, optional
         The name of the node.
 
@@ -85,8 +85,8 @@ class MsPhases(Node):
 
     See Also
     --------
-    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_ion_chain_properties` : Function to
-        calculate the properties of an ion chain.
+    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_ion_chain_properties` :
+        Function to calculate the properties of an ion chain.
     ms_infidelity : Final operational infidelity of a Mølmer–Sørensen gate.
     ms_phases_multitone : Corresponding operation for a global multitone beam.
 
@@ -96,7 +96,7 @@ class MsPhases(Node):
 
     .. math::
         H_0 = \sum_{p = 1}^{3N} \hbar\nu_p \left(a_p^\dagger a_p + \frac{1}{2}\right)
-            + \sum_{j =1}^N \frac{\hbar \omega_0}{2} \sigma_{z,j} \;,
+            + \sum_{j = 1}^N \frac{\hbar \omega_0}{2} \sigma_{z,j} ,
 
     where the axis dimension and collective mode dimension are combined into a single index
     :math:`p` for simplicity, :math:`a_p` is the annihilation operator for the mode :math:`p`,
@@ -106,7 +106,7 @@ class MsPhases(Node):
 
     .. math::
         H_I(t) = i\hbar\sum_{j = 1}^N \sigma_{x, j} \sum_{p = 1}^{3N} (-\beta_{pj}^*(t)a_p +
-                \beta_{pj}(t) a_p^\dagger) \;,
+                \beta_{pj}(t) a_p^\dagger) ,
 
     where :math:`\sigma_{x, j}` is the Pauli :math:`X` operator for the ion :math:`j` and
     :math:`\beta_{pj}(t) = \eta_{pj} \frac{\gamma_j(t)}{2} e^{i\delta_p t}`,
@@ -116,20 +116,24 @@ class MsPhases(Node):
     .. math::
         U(t) = \exp\left[ \sum_{j=1}^N \sigma_{x, j} B_j(t)
                 + i\sum_{j=1}^N\sum_{k=1}^{j - 1} (\phi_{jk}(t) + \phi_{kj}(t))
-                \sigma_{x, j} \sigma_{x, k} \right] \;,
+                \sigma_{x, j} \sigma_{x, k} \right] ,
 
     where
 
     .. math::
         B_j(t) &\equiv \sum_{p = 1}^{3N}  \left(\eta_{pj}\alpha_{pj}(t)a_p^\dagger
-             - \eta_{pj}^{\ast}\alpha_{pj}^\ast(t)a_p \right) \;,
+             - \eta_{pj}^{\ast}\alpha_{pj}^\ast(t)a_p \right) ,
 
         \phi_{jk}(t) &\equiv \mathrm{Im} \left[ \sum_{p=1}^{3N} \int_{0}^{t} d \tau_1
-            \int_{0}^{\tau_1} d \tau_2 \beta_{pj}(\tau_1)\beta_{pk}^{\ast}(\tau_2) \right] \;,
+            \int_{0}^{\tau_1} d \tau_2 \beta_{pj}(\tau_1)\beta_{pk}^{\ast}(\tau_2) \right] ,
 
-    with :math:`\alpha_{pj}(t) = \int_0^t d\tau \frac{\gamma_j(\tau)}{2} e^{i \delta_p \tau}`.
+    and
 
-    This function calculates the relative phases :math:`\phi_{jk}(t_i) + \phi_{kj}(t_i)`
+    .. math::
+        \alpha_{pj}(t) = \int_0^t d\tau \frac{\gamma_j(\tau)}{2} e^{i \delta_p \tau} .
+
+    This function calculates the relative phases
+    :math:`\Phi_{jk}(t_i) = \phi_{jk}(t_i) + \phi_{kj}(t_i)`
     for all ions pairs at time :math:`t_i` and stores the result in the form of a strictly
     lower triangular matrix. That is, the :math:`jk`-th element of
     that matrix records the relative phase between the ion :math:`j` and :math:`k`,
@@ -165,6 +169,9 @@ class MsPhases(Node):
         lamb_dicke_parameters = kwargs.get("lamb_dicke_parameters")
         relative_detunings = kwargs.get("relative_detunings")
         check_argument_iterable(drives, "drives")
+        check_argument(
+            len(drives) > 0, "At least one drive must be provided.", {"drives": drives}
+        )
         check_argument(
             all(isinstance(drive, Pwc) for drive in drives),
             "Each of the drives must be a Pwc.",
@@ -185,7 +192,9 @@ class MsPhases(Node):
             rd_name="relative_detunings",
         )
         if sample_times is not None:
-            check_sample_times(sample_times, "sample_times")
+            check_sample_times_with_bounds(
+                sample_times, "sample_times", drives[0], "drives[0]"
+            )
             time_count = len(sample_times)
             shape = (time_count,) + tuple(shape)
         return Tensor(_operation, shape=shape)
@@ -193,7 +202,7 @@ class MsPhases(Node):
 
 class MsPhasesMultitone(Node):
     r"""
-    Calculates the relative phases for all pairs of ions described by a
+    Calculate the relative phases for all pairs of ions described by a
     Mølmer–Sørensen-type interaction where the ions are being addressed by
     a multitone global beam.
 
@@ -227,10 +236,10 @@ class MsPhasesMultitone(Node):
         the second dimension :math:`j` indicates the axis and the third
         dimension :math:`k` indicates the collective mode number.
     sample_times : np.ndarray, optional
-         A 1D array of length :math:`T` specifying the times :math:`\{t_i\}` (in seconds) at which
-         this function calculates the relative phases.
-         If you omit it, this function calculates the phases only at the final time of the drives.
-         If provided, it must be ordered and contain at least one element.
+        A 1D array of length :math:`T` specifying the times :math:`\{t_i\}` (in seconds) at which
+        this function calculates the relative phases.
+        If you omit it, this function calculates the phases only at the final time of the drives.
+        If provided, it must be ordered and contain at least one element.
     name : str, optional
         The name of the node.
 
@@ -246,8 +255,8 @@ class MsPhasesMultitone(Node):
 
     See Also
     --------
-    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_ion_chain_properties` : Function to
-        calculate the properties of an ion chain.
+    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_ion_chain_properties` :
+        Function to calculate the properties of an ion chain.
     ms_infidelity : Final operational infidelity of a Mølmer–Sørensen gate.
     ms_phases: Corresponding operation for single-tone individually-addressed beams.
 
@@ -258,7 +267,7 @@ class MsPhasesMultitone(Node):
 
     .. math::
         H_I(t) = i\hbar\sum_{j = 1}^N \sigma_{x, j} \sum_{p = 1}^{3N} \sum_{\xi = 1}^M
-                 (-\beta_{\xi pj}^*(t)a_p + \beta_{\xi pj}(t) a_p^\dagger) \;,
+                 (-\beta_{\xi pj}^*(t)a_p + \beta_{\xi pj}(t) a_p^\dagger) ,
 
     where :math:`\sigma_{x, j}` is the Pauli :math:`X` operator for the ion :math:`j` and
     :math:`\beta_{\xi pj}(t) = \eta_{\xi pj} \frac{\gamma_\xi(t)}{2} e^{i\delta_{\xi p} t}`,
@@ -268,18 +277,18 @@ class MsPhasesMultitone(Node):
     .. math::
         U(t) = \exp\left[ \sum_{j=1}^N \sigma_{x, j} B_j(t)
                 + i\sum_{j=1}^N \sum_{k=1}^{j - 1} (\phi_{jk}(t) + \phi_{kj}(t))
-                \sigma_{x, j} \sigma_{x, k} \right] \;,
+                \sigma_{x, j} \sigma_{x, k} \right] ,
 
     where
 
     .. math::
         B_j(t) &\equiv \sum_{p = 1}^{3N} \sum_{\xi = 1}^M
              \left(\eta_{\xi pj}\alpha_{\xi pj}(t)a_p^\dagger
-             - \eta_{\xi pj}^{\ast}\alpha_{\xi pj}^\ast(t)a_p \right) \;,
+             - \eta_{\xi pj}^{\ast}\alpha_{\xi pj}^\ast(t)a_p \right) ,
 
         \phi_{jk}(t) &\equiv \mathrm{Im} \left[ \sum_{p=1}^{3N} \sum_{\xi_1 = 1}^M
             \sum_{\xi_2 = 1}^M \int_{0}^{t} d \tau_1 \int_{0}^{\tau_1} d \tau_2
-            \beta_{\xi_1 pj}(\tau_1)\beta_{\xi_2 pk}^{\ast}(\tau_2) \right] \;,
+            \beta_{\xi_1 pj}(\tau_1)\beta_{\xi_2 pk}^{\ast}(\tau_2) \right] ,
 
     with :math:`\alpha_{\xi pj}(t) = \int_0^t d\tau \frac{\gamma_\xi(\tau)}{2}
     e^{i \delta_{\xi p} \tau}`.
@@ -308,6 +317,9 @@ class MsPhasesMultitone(Node):
         lamb_dicke_parameters = kwargs.get("lamb_dicke_parameters")
         relative_detunings = kwargs.get("relative_detunings")
         check_argument_iterable(drives, "drives")
+        check_argument(
+            len(drives) > 0, "At least one drive must be provided.", {"drives": drives}
+        )
         check_argument(
             all(isinstance(drive, Pwc) for drive in drives),
             "Each of the drives must be a Pwc.",
@@ -350,7 +362,9 @@ class MsPhasesMultitone(Node):
 
         shape = (ion_count, ion_count)
         if sample_times is not None:
-            check_sample_times(sample_times, "sample_times")
+            check_sample_times_with_bounds(
+                sample_times, "sample_times", drives[0], "drives[0]"
+            )
             time_count = len(sample_times)
             shape = (time_count,) + shape
 
@@ -359,7 +373,7 @@ class MsPhasesMultitone(Node):
 
 class MsDisplacements(Node):
     r"""
-    Calculates the displacements for each mode and ion combination where ions are described by
+    Calculate the displacements for each mode and ion combination where ions are described by
     a Mølmer–Sørensen-type interaction.
 
     Use this function to calculate the displacements for each ion and each mode
@@ -385,10 +399,10 @@ class MsDisplacements(Node):
         Its shape must be ``(3, N)`` where the first dimension :math:`j` indicates the axis and the
         second dimension :math:`k` indicates the collective mode number.
     sample_times : np.ndarray, optional
-         A 1D array of length :math:`T` specifying the times :math:`\{t_i\}` (in seconds) at which
-         this function calculates the displacements.
-         If you omit it, this function calculates the phases only at the final time of the drives.
-         If provided, it must be ordered and contain at least one element.
+        A 1D array of length :math:`T` specifying the times :math:`\{t_i\}` (in seconds) at which
+        this function calculates the displacements.
+        If you omit it, this function calculates the phases only at the final time of the drives.
+        If provided, it must be ordered and contain at least one element.
     name : str, optional
         The name of the node.
 
@@ -403,8 +417,8 @@ class MsDisplacements(Node):
 
     See Also
     --------
-    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_ion_chain_properties` : Function to
-        calculate the properties of an ion chain.
+    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_ion_chain_properties` :
+        Function to calculate the properties of an ion chain.
     ms_infidelity : Final operational infidelity of a Mølmer–Sørensen gate.
 
     Notes
@@ -413,7 +427,7 @@ class MsDisplacements(Node):
 
     .. math::
         H_0 = \sum_{p = 1}^{3N} \hbar\nu_p \left(a_p^\dagger a_p + \frac{1}{2}\right)
-            + \sum_{j =1}^N \frac{\hbar \omega_0}{2} \sigma_{z,j} \;,
+            + \sum_{j = 1}^N \frac{\hbar \omega_0}{2} \sigma_{z,j} ,
 
     where the axis dimension and collective mode dimension are combined into a single index
     :math:`p` for simplicity, :math:`a_p` is the annihilation operator for the mode :math:`p`,
@@ -423,7 +437,7 @@ class MsDisplacements(Node):
 
     .. math::
         H_I(t) = i\hbar\sum_{j = 1}^N \sigma_{x, j} \sum_{p = 1}^{3N} (-\beta_{pj}^*(t)a_p +
-                \beta_{pj}(t) a_p^\dagger) \;,
+                \beta_{pj}(t) a_p^\dagger) ,
 
     where :math:`\sigma_{x, j}` is the Pauli :math:`X` operator for the ion :math:`j` and
     :math:`\beta_{pj}(t) = \eta_{pj} \frac{\gamma_j(t)}{2} e^{i\delta_p t}`,
@@ -433,21 +447,21 @@ class MsDisplacements(Node):
     .. math::
         U(t) = \exp\left[ \sum_{j=1}^N \sigma_{x, j} B_j(t)
                 + i\sum_{j=1}^N\sum_{k=1}^{j - 1} (\phi_{jk}(t) + \phi_{kj}(t))
-                \sigma_{x, j} \sigma_{x, k} \right] \;,
+                \sigma_{x, j} \sigma_{x, k} \right] ,
 
     where
 
     .. math::
         B_j(t) &\equiv \sum_{p = 1}^{3N}  \left(\eta_{pj}\alpha_{pj}(t)a_p^\dagger
-             - \eta_{pj}^{\ast}\alpha_{pj}^\ast(t)a_p \right) \;,
+             - \eta_{pj}^{\ast}\alpha_{pj}^\ast(t)a_p \right) ,
 
         \phi_{jk}(t) &\equiv \mathrm{Im} \left[ \sum_{p=1}^{3N} \int_{0}^{t} d \tau_1
-            \int_{0}^{\tau_1} d \tau_2 \beta_{pj}(\tau_1)\beta_{pk}^{\ast}(\tau_2) \right] \;,
+            \int_{0}^{\tau_1} d \tau_2 \beta_{pj}(\tau_1)\beta_{pk}^{\ast}(\tau_2) \right] ,
 
     and
 
     .. math::
-        \alpha_{pj}(t) = \int_0^t d\tau \frac{\gamma_j(\tau)}{2} e^{i \delta_p \tau} \;.
+        \alpha_{pj}(t) = \int_0^t d\tau \frac{\gamma_j(\tau)}{2} e^{i \delta_p \tau} .
 
     This function calculates, for each time :math:`t_i`, the contribution to the displacement of
     mode :math:`p` from the ion :math:`j`, namely :math:`\eta_{pj}\alpha_{pj}(t_i)`. You can
@@ -457,7 +471,7 @@ class MsDisplacements(Node):
     :math:`t_i` is:
 
     .. math::
-        \mathcal{D}_p \left(\sum_{j =1}^N \sigma_{x, j}\eta_{pj}\alpha_{pj}(t_i) \right)\;.
+        \mathcal{D}_p \left(\sum_{j = 1}^N \sigma_{x, j}\eta_{pj}\alpha_{pj}(t_i) \right) .
 
     References
     ----------
@@ -489,6 +503,9 @@ class MsDisplacements(Node):
         lamb_dicke_parameters = kwargs.get("lamb_dicke_parameters")
         relative_detunings = kwargs.get("relative_detunings")
         check_argument_iterable(drives, "drives")
+        check_argument(
+            len(drives) > 0, "At least one drive must be provided.", {"drives": drives}
+        )
         check_argument(
             all(isinstance(drive, Pwc) for drive in drives),
             "Each of the drives must be a Pwc.",
@@ -509,7 +526,9 @@ class MsDisplacements(Node):
             rd_name="relative_detunings",
         )
         if sample_times is not None:
-            check_sample_times(sample_times, "sample_times")
+            check_sample_times_with_bounds(
+                sample_times, "sample_times", drives[0], "drives[0]"
+            )
             time_count = len(sample_times)
             shape = (time_count,) + tuple(shape)
         return Tensor(_operation, shape=shape)
@@ -517,16 +536,16 @@ class MsDisplacements(Node):
 
 class MsInfidelity(Node):
     r"""
-    Calculates the final operational infidelity of the Mølmer–Sørensen gate.
+    Calculate the final operational infidelity of the Mølmer–Sørensen gate.
 
     This function calculates the operational infidelity with respect to the target phases
-    that you specify in the `target_phases` array. It can use the tensors returned from `ms_phases`
-    and `ms_displacements` to calculate the infidelity tensor.
+    that you specify in the `target_phases` array. It can use the tensors returned from
+    :func:`ms_phases` and :func:`ms_displacements` to calculate the infidelity tensor.
 
     Parameters
     ----------
     phases : np.ndarray(real) or Tensor(real)
-        Acquired phases :math:`\{\phi_{kl}\}` for all ion pairs with shape ``(N, N)`` without time
+        Acquired phases :math:`\{\Phi_{kl}\}` for all ion pairs with shape ``(N, N)`` without time
         samples or ``(T, N, N)``, where ``T`` is the number of samples and ``N`` is the
         number of ions. For each sample the `phases` array must be a strictly lower
         triangular matrix.
@@ -568,10 +587,9 @@ class MsInfidelity(Node):
 
     .. math::
         1 - \mathcal{F}_\mathrm{av} = 1 - \left| \left( \prod_{\substack{k=1 \\ l<k}}^N \cos (
-            \phi_{kl} - \psi_{kl}) \right)
+            \Phi_{kl} - \psi_{kl}) \right)
             \left( 1 - \sum_{j=1}^3 \sum_{k,l=1}^N \left[ |\eta_{jkl}|^2
-            |\alpha_{jkl}|^2 \left(\bar{n}_{jk}+\frac{1}{2} \right) \right] \right) \right|^2
-        \;.
+            |\alpha_{jkl}|^2 \left(\bar{n}_{jk}+\frac{1}{2} \right) \right] \right) \right|^2 .
 
     References
     ----------
@@ -668,7 +686,7 @@ class MsInfidelity(Node):
 
 class MsDephasingRobustCost(Node):
     r"""
-    Calculates the cost for robust optimization of a Mølmer–Sørensen gate.
+    Calculate the cost for robust optimization of a Mølmer–Sørensen gate.
 
     Add the tensor that this function returns to the infidelity of your
     target operation to obtain a cost that you can use to create a
@@ -711,8 +729,8 @@ class MsDephasingRobustCost(Node):
 
     See Also
     --------
-    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_ion_chain_properties` : Function to
-        calculate the properties of an ion chain.
+    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_ion_chain_properties` :
+        Function to calculate the properties of an ion chain.
     ms_infidelity : Final operational infidelity of a Mølmer–Sørensen gate.
 
     Notes
@@ -727,7 +745,7 @@ class MsDephasingRobustCost(Node):
 
     .. math::
         \alpha_{pj}(t) = \int_0^t d\tau \frac{\gamma_j(\tau)}{2}
-        e^{i \delta_p \tau} \;.
+        e^{i \delta_p \tau} .
 
     where the axis dimension and the collective mode dimension are combined
     into a single index :math:`p` for simplicity. For a gate of duration
@@ -735,7 +753,7 @@ class MsDephasingRobustCost(Node):
 
     .. math::
         \langle \alpha_{pj} \rangle = \frac{1}{t_\text{gate}}
-        \int_0^{t_\text{gate}} \alpha_{pj}(t) \mathrm{d} t \;.
+        \int_0^{t_\text{gate}} \alpha_{pj}(t) \mathrm{d} t .
 
     This function returns the sum of the square moduli of the time-averaged
     positions multiplied by the corresponding Lamb–Dicke parameters. These
@@ -785,6 +803,9 @@ class MsDephasingRobustCost(Node):
         lamb_dicke_parameters = kwargs.get("lamb_dicke_parameters")
         relative_detunings = kwargs.get("relative_detunings")
         check_argument_iterable(drives, "drives")
+        check_argument(
+            len(drives) > 0, "At least one drive must be provided.", {"drives": drives}
+        )
         check_argument(
             all(isinstance(drive, Pwc) for drive in drives),
             "Each of the drives must be a Pwc.",
