@@ -36,7 +36,7 @@ from qctrlcommons.preconditions import (
 
 class OptimizationVariable(Node):
     r"""
-    Creates optimization variables, which can be bounded, semi-bounded, or unbounded.
+    Create optimization variables, which can be bounded, semi-bounded, or unbounded.
 
     Use this function to create a sequence of variables that can be tuned by
     the optimizer (within specified bounds) in order to minimize the cost
@@ -149,7 +149,7 @@ class OptimizationVariable(Node):
 
 class AnchoredDifferenceBoundedVariables(Node):
     r"""
-    Creates a sequence of optimizable variables with an anchored difference bound.
+    Create a sequence of optimizable variables with an anchored difference bound.
 
     Use this function to create a sequence of optimization variables that have
     a difference bound (each variable is constrained to be within a given
@@ -190,8 +190,10 @@ class AnchoredDifferenceBoundedVariables(Node):
 
     See Also
     --------
-    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_optimization` : Function to find
-        the minimum of generic functions.
+    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_optimization` :
+        Function to find the minimum of generic deterministic functions.
+    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_stochastic_optimization` :
+        Function to find the minimum of generic stochastic functions.
     optimization_variable : Create optimization variables.
 
     Examples
@@ -207,7 +209,7 @@ class AnchoredDifferenceBoundedVariables(Node):
     See the "Band-limited pulses with bounded slew rates" example in the
     `How to add smoothing and band-limits to optimized controls
     <https://docs.q-ctrl.com/boulder-opal/user-guides/how-to-add-smoothing-and-band-limits-to-
-    optimized-controls#Worked-example:-Band-limited-pulses-with-bounded-slew-rates>`_ user guide.
+    optimized-controls#worked-example-band-limited-pulses-with-bounded-slew-rates>`_ user guide.
     """
 
     name = "anchored_difference_bounded_variables"
@@ -240,7 +242,7 @@ class AnchoredDifferenceBoundedVariables(Node):
 
 class RealFourierStfSignal(Node):
     r"""
-    Creates a real sampleable signal constructed from Fourier components.
+    Create a real sampleable signal constructed from Fourier components.
 
     Use this function to create a signal defined in terms of Fourier (sine/cosine)
     basis signals that can be optimized by varying their coefficients and, optionally,
@@ -352,7 +354,7 @@ class RealFourierStfSignal(Node):
 
 class RealFourierPwcSignal(Node):
     r"""
-    Creates a piecewise-constant signal constructed from Fourier components.
+    Create a piecewise-constant signal constructed from Fourier components.
 
     Use this function to create a signal defined in terms of Fourier
     (sine/cosine) basis signals that can be optimized by varying their
@@ -443,7 +445,7 @@ class RealFourierPwcSignal(Node):
     See the "CRAB optimization on a qutrit" example in the
     `How to perform model-based optimization using a Fourier basis
     <https://docs.q-ctrl.com/boulder-opal/user-guides/how-to-perform-model-based-optimization-
-    using-a-fourier-basis#Worked-example:-CRAB-optimization-on-a-qutrit>`_ user guide.
+    using-a-fourier-basis#worked-example-crab-optimization-on-a-qutrit>`_ user guide.
     """
 
     name = "real_fourier_pwc_signal"
