@@ -11,7 +11,7 @@
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
 """
-Module for all the node related to PWC.
+Module for PWC-related nodes.
 """
 from typing import (
     List,
@@ -22,7 +22,6 @@ import forge
 import numpy as np
 
 from qctrlcommons.node.base import Node
-from qctrlcommons.node.deprecation import deprecated_node
 from qctrlcommons.node.documentation import Category
 from qctrlcommons.node.node_data import (
     Pwc,
@@ -31,6 +30,7 @@ from qctrlcommons.node.node_data import (
 from qctrlcommons.node.utils import (
     TensorLike,
     get_broadcasted_shape,
+    mesh_pwc_durations,
     validate_batch_and_value_shapes,
     validate_hamiltonian,
     validate_shape,
@@ -42,13 +42,13 @@ from qctrlcommons.preconditions import (
     check_argument_numeric,
     check_duration,
     check_operator,
-    check_sample_times,
+    check_sample_times_with_bounds,
 )
 
 
 class PwcOperation(Node):
     r"""
-    Creates a piecewise-constant function of time.
+    Create a piecewise-constant function of time.
 
     Parameters
     ----------
@@ -89,6 +89,12 @@ class PwcOperation(Node):
     pwc_signal : Create `Pwc` signals from (possibly complex) values.
     pwc_sum : Sum multiple `Pwc`\s.
 
+    Notes
+    -----
+    For more information on `Pwc` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
+
     Examples
     --------
     Create a Hamiltonian from a piecewise-constant signal with non-uniform segment durations.
@@ -112,7 +118,6 @@ class PwcOperation(Node):
     See more examples in the `How to simulate quantum dynamics subject to noise with graphs
     <https://docs.q-ctrl.com/boulder-opal/user-guides/how-to-simulate-
     quantum-dynamics-subject-to-noise-with-graphs>`_ user guide.
-
     """
 
     name = "pwc"
@@ -130,10 +135,20 @@ class PwcOperation(Node):
         durations = kwargs.get("durations")
         values = kwargs.get("values")
         time_dimension = kwargs.get("time_dimension")
+        check_argument(
+            durations.size != 0,
+            "The `durations` must be a non-empty array.",
+            {"durations": durations},
+        )
         check_argument_numeric(durations, "durations")
         check_argument_numeric(values, "values")
         check_argument_integer(time_dimension, "time_dimension")
         value_shape = validate_shape(values, "values")
+        check_argument(
+            len(value_shape) > 0 and value_shape != (0,),
+            "The `values` must be a non-empty array or Tensor.",
+            {"values": values},
+        )
         durations_shape = validate_shape(durations, "durations")
         check_argument(
             len(durations_shape) == 1,
@@ -169,7 +184,7 @@ class PwcOperation(Node):
 
 class PwcSignal(Node):
     r"""
-    Creates a piecewise-constant signal (scalar-valued function of time).
+    Create a piecewise-constant signal (scalar-valued function of time).
 
     Use this function to create a piecewise-constant signal in which the
     constant segments all have the same duration.
@@ -206,6 +221,12 @@ class PwcSignal(Node):
     pwc_sum : Sum multiple `Pwc`\s.
     symmetrize_pwc : Symmetrize `Pwc`\s.
 
+    Notes
+    -----
+    For more information on `Pwc` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
+
     Examples
     --------
     Create a piecewise-constant signal with uniform segment duration.
@@ -245,7 +266,7 @@ class PwcSignal(Node):
 
 class ComplexPwcSignal(Node):
     r"""
-    Creates a complex piecewise-constant signal from moduli and phases.
+    Create a complex piecewise-constant signal from moduli and phases.
 
     Use this function to create a complex piecewise-constant signal from
     moduli and phases defined for each segment, in which the constant segments
@@ -284,6 +305,12 @@ class ComplexPwcSignal(Node):
     --------
     pwc_signal : Create `Pwc` signals from (possibly complex) values.
 
+    Notes
+    -----
+    For more information on `Pwc` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
+
     Examples
     --------
     Create a complex piecewise-constant signal with batched moduli and phases.
@@ -350,7 +377,7 @@ class ComplexPwcSignal(Node):
 
 class PwcOperator(Node):
     r"""
-    Creates a constant operator multiplied by a piecewise-constant signal.
+    Create a constant operator multiplied by a piecewise-constant signal.
 
     Parameters
     ----------
@@ -379,6 +406,12 @@ class PwcOperator(Node):
     pwc_sum : Sum multiple `Pwc`\s.
     stf_operator : Corresponding operation for `Stf`\s.
 
+    Notes
+    -----
+    For more information on `Pwc` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
+
     Examples
     --------
     Create a piecewise-constant operator with non-uniform segment durations.
@@ -441,7 +474,7 @@ class PwcOperator(Node):
 
 class ConstantPwcOperator(Node):
     r"""
-    Creates a constant piecewise-constant operator over a specified duration.
+    Create a constant piecewise-constant operator over a specified duration.
 
     Parameters
     ----------
@@ -466,6 +499,12 @@ class ConstantPwcOperator(Node):
     hermitian_part : Hermitian part of an operator.
     pwc_operator : Create `Pwc` operators.
 
+    Notes
+    -----
+    For more information on `Pwc` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
+
     Examples
     --------
     Create a Hamiltonian from a batched constant operator.
@@ -509,7 +548,7 @@ class ConstantPwcOperator(Node):
 
 class ConstantPwc(Node):
     r"""
-    Creates a piecewise-constant function of time that is constant over a specified duration.
+    Create a piecewise-constant function of time that is constant over a specified duration.
 
     Parameters
     ----------
@@ -540,6 +579,12 @@ class ConstantPwc(Node):
     constant_stf : Corresponding operation for `Stf`\s.
     pwc : Create piecewise-constant functions.
 
+    Notes
+    -----
+    For more information on `Pwc` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
+
     Examples
     --------
     Create a batched piecewise-constant function.
@@ -602,83 +647,9 @@ class ConstantPwc(Node):
         )
 
 
-@deprecated_node(updated_node_name="hermitian_part")  # deprecated 2022/04/21
-class PwcOperatorHermitianPart(Node):
-    # pylint:disable=line-too-long
-    r"""
-    Creates the Hermitian part of a piecewise-constant operator.
-
-    Parameters
-    ----------
-    operator : Pwc
-        The operator :math:`A(t)`, or a batch of operators.
-    name : str, optional
-        The name of the node.
-
-    Returns
-    -------
-    Pwc
-        The Hermitian part :math:`\frac{1}{2}(A(t)+A^\dagger(t))`
-        (or a batch of Hermitian parts, if you provide a batch of operators).
-
-    See Also
-    --------
-    constant_pwc_operator : Create constant `Pwc`\s.
-    pwc_operator : Create `Pwc` operators.
-    sparse_pwc_hermitian_part : Create the Hermitian part of a `SparsePwc` operator.
-
-    Examples
-    --------
-    Creates a Hamiltonian from a non-Hermitian operator.
-
-    >>> omega = graph.pwc(durations=np.array([0.1, 0.2]), values=np.array([0.2, 0.4]))
-    >>> sigma_m = np.array([[0, 1], [0, 0]])
-    >>> operator = omega * sigma_m
-    >>> graph.pwc_operator_hermitian_part(operator=operator, name="hamiltonian")
-    <Pwc: name="hamiltonian", operation_name="pwc_operator_hermitian_part", value_shape=(2, 2), batch_shape=()>
-    >>> result = qctrl.functions.calculate_graph(graph=graph, output_node_names=["hamiltonian"])
-    >>> result.output["hamiltonian"]
-    [
-        {"value": array([[0.0, 0.1], [0.1, 0.0]]), "duration": 0.1},
-        {"value": array([[0.0, 0.2], [0.2, 0.0]]), "duration": 0.2},
-    ]
-
-    See more examples in the `Simulate the dynamics of a single qubit using computational graphs
-    <https://docs.q-ctrl.com/boulder-opal/tutorials/simulate-the-dynamics-of-a-single-qubit-
-    using-computational-graphs>`_ tutorial.
-    """
-
-    # pylint:enable=line-too-long
-    name = "pwc_operator_hermitian_part"
-    args = [forge.arg("operator", type=Pwc)]
-    rtype = Pwc
-    categories = [Category.BUILDING_PIECEWISE_CONSTANT_HAMILTONIANS]
-
-    @classmethod
-    def create_node_data(cls, _operation, **kwargs):
-        operator = kwargs.get("operator")
-        check_argument(
-            isinstance(operator, Pwc),
-            "The operator must be a Pwc.",
-            {"operator": operator},
-        )
-        batch_shape, value_shape = validate_batch_and_value_shapes(operator, "operator")
-        check_argument(
-            len(value_shape) == 2 and value_shape[0] == value_shape[1],
-            "The values of the operator must be a square matrix.",
-            {"operator": operator},
-        )
-        return Pwc(
-            _operation,
-            value_shape=value_shape,
-            durations=operator.durations,
-            batch_shape=batch_shape,
-        )
-
-
 class PwcSum(Node):
     r"""
-    Creates the sum of multiple piecewise-constant terms.
+    Create the sum of multiple piecewise-constant terms.
 
     Parameters
     ----------
@@ -709,6 +680,12 @@ class PwcSum(Node):
     pwc_signal : Create `Pwc` signals from (possibly complex) values.
     stf_sum : Corresponding operation for `Stf`\s.
 
+    Notes
+    -----
+    For more information on `Pwc` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
+
     Examples
     --------
     Sum a list of piecewise-constant terms of different durations.
@@ -749,15 +726,16 @@ class PwcSum(Node):
         )
         batch_shape, value_shape = validate_batch_and_value_shapes(terms[0], "terms[0]")
         check_argument(
-            all(
-                (
-                    (term.value_shape == value_shape)
-                    and (term.batch_shape == batch_shape)
-                )
-                for term in terms[1:]
-            ),
-            "All the terms must have the same shape.",
+            all(term.value_shape == value_shape for term in terms[1:]),
+            "All the terms must have the same value shape.",
             {"terms": terms},
+            extras={"value shapes of terms": [term.value_shape for term in terms]},
+        )
+        check_argument(
+            all(term.batch_shape == batch_shape for term in terms[1:]),
+            "All the terms must have the same batch shape.",
+            {"terms": terms},
+            extras={"batch shapes of terms": [term.batch_shape for term in terms]},
         )
         check_argument(
             all(
@@ -772,26 +750,19 @@ class PwcSum(Node):
                 ]
             },
         )
-        upsampled_durations = np.diff(
-            np.insert(
-                np.unique(
-                    np.concatenate([np.cumsum(term.durations) for term in terms])
-                ),
-                0,
-                0,
-            )
-        )
+        durations = mesh_pwc_durations(terms)
+
         return Pwc(
             _operation,
             value_shape=value_shape,
-            durations=upsampled_durations,
+            durations=durations,
             batch_shape=batch_shape,
         )
 
 
 class TimeReversePwc(Node):
     r"""
-    Reverses in time a piecewise-constant function.
+    Reverse in time a piecewise-constant function.
 
     Parameters
     ----------
@@ -812,6 +783,12 @@ class TimeReversePwc(Node):
     symmetrize_pwc : Symmetrize `Pwc`\s.
     time_concatenate_pwc : Concatenate `Pwc`\s in time.
 
+    Notes
+    -----
+    For more information on `Pwc` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
+
     Examples
     --------
     Reverse a piecewise constant function.
@@ -849,7 +826,7 @@ class TimeReversePwc(Node):
 
 class SymmetrizePwc(Node):
     r"""
-    Creates the symmetrization of a piecewise-constant function.
+    Create the symmetrization of a piecewise-constant function.
 
     Parameters
     ----------
@@ -871,6 +848,12 @@ class SymmetrizePwc(Node):
     pwc_signal : Create `Pwc` signals from (possibly complex) values.
     time_reverse_pwc : Reverse `Pwc`\s in time.
 
+    Notes
+    -----
+    For more information on `Pwc` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
+
     Examples
     --------
     Create a symmetric piecewise-constant function.
@@ -915,7 +898,7 @@ class SymmetrizePwc(Node):
 
 class TimeConcatenatePwc(Node):
     r"""
-    Concatenates multiple piecewise-constant functions in the time dimension.
+    Concatenate multiple piecewise-constant functions in the time dimension.
 
     Parameters
     ----------
@@ -930,6 +913,13 @@ class TimeConcatenatePwc(Node):
     Pwc
         The concatenated piecewise-constant function (or batch of functions).
 
+    See Also
+    --------
+    pwc : Create piecewise-constant functions.
+    pwc_sum : Sum multiple `Pwc`\s.
+    symmetrize_pwc : Symmetrize `Pwc`\s.
+    time_reverse_pwc : Reverse `Pwc`\s in time.
+
     Notes
     -----
     The function resulting from the concatenation is
@@ -947,12 +937,9 @@ class TimeConcatenatePwc(Node):
 
     where :math:`\tau_i` is the duration of the i-th function.
 
-    See Also
-    --------
-    pwc : Create piecewise-constant functions.
-    pwc_sum : Sum multiple `Pwc`\s.
-    symmetrize_pwc : Symmetrize `Pwc`\s.
-    time_reverse_pwc : Reverse `Pwc`\s in time.
+    For more information on `Pwc` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
 
     Examples
     --------
@@ -1014,7 +1001,7 @@ class TimeConcatenatePwc(Node):
 
 class TimeEvolutionOperatorsPwc(Node):
     """
-    Calculates the unitary time-evolution operators for a system defined by a piecewise-constant
+    Calculate the unitary time-evolution operators for a system defined by a piecewise-constant
     Hamiltonian.
 
     Parameters
@@ -1039,6 +1026,12 @@ class TimeEvolutionOperatorsPwc(Node):
     state_evolution_pwc : Evolve a quantum state.
     time_evolution_operators_stf : Corresponding operation for `Stf` Hamiltonians.
 
+    Notes
+    -----
+    For more information on `Pwc` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
+
     Examples
     --------
     Simulate the dynamics of a single qubit, where a constant drive rotates the
@@ -1081,7 +1074,9 @@ class TimeEvolutionOperatorsPwc(Node):
         batch_shape, value_shape = validate_batch_and_value_shapes(
             hamiltonian, "hamiltonian"
         )
-        check_sample_times(sample_times, "sample_times")
+        check_sample_times_with_bounds(
+            sample_times, "sample_times", hamiltonian, "hamiltonian"
+        )
         validate_hamiltonian(hamiltonian, "hamiltonian")
         time_count = len(sample_times)
         shape = batch_shape + (time_count,) + value_shape
@@ -1090,7 +1085,7 @@ class TimeEvolutionOperatorsPwc(Node):
 
 class SamplePwc(Node):
     r"""
-    Samples a Pwc at the given times.
+    Sample a Pwc at the given times.
 
     Parameters
     ----------
@@ -1113,6 +1108,12 @@ class SamplePwc(Node):
     See Also
     --------
     sample_stf : Sample an `Stf` at given times.
+
+    Notes
+    -----
+    For more information on `Pwc` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
     """
 
     name = "sample_pwc"
@@ -1126,7 +1127,7 @@ class SamplePwc(Node):
         check_argument(isinstance(pwc, Pwc), "The pwc must be a Pwc.", {"pwc": pwc})
         batch_shape, value_shape = validate_batch_and_value_shapes(pwc, "pwc")
         sample_times = kwargs.get("sample_times")
-        check_sample_times(sample_times, "sample_times")
+        check_sample_times_with_bounds(sample_times, "sample_times", pwc, "pwc")
         check_argument(
             sample_times[0] >= 0,
             "The first sample time can't be smaller than zero.",
