@@ -47,7 +47,9 @@ TYPE_REGISTRY = [
 
 
 class NodeRegistry:
-    """Register all the imported Node type class."""
+    """
+    Register all the imported Node type class.
+    """
 
     def __init__(self, nodes):
         self._nodes = {}
@@ -62,7 +64,8 @@ class NodeRegistry:
             self._nodes[node.name] = node
 
     def get_node_cls(self, name: str) -> Node.__class__:
-        """Get the Node class by name from the operation.
+        """
+        Get the Node class by name from the operation.
 
         Parameters
         ----------
@@ -85,8 +88,10 @@ class NodeRegistry:
         return self._nodes[name]
 
     def as_list(self, exclude_node_types=None) -> List:
-        """Converts the nodes to a list. Allows exclusion of certain nodes, if
-        not all nodes are needed.
+        """
+        Convert the nodes to a list.
+
+        This method allows exclusion of certain nodes, if not all nodes are needed.
 
         Parameters
         ----------
@@ -121,7 +126,8 @@ class NodeRegistry:
 
     @classmethod
     def load(cls):
-        """Load all the register Node class.
+        """
+        Load all the register Node class.
 
         Parameters
         ----------
