@@ -32,6 +32,7 @@ from qctrlcommons.node.node_data import (
 )
 from qctrlcommons.node.utils import (
     TensorLike,
+    mesh_pwc_durations,
     validate_hamiltonian,
     validate_shape,
 )
@@ -42,13 +43,13 @@ from qctrlcommons.preconditions import (
     check_argument_numeric,
     check_duration,
     check_operator,
-    check_sample_times,
+    check_sample_times_with_bounds,
 )
 
 
 class SparsePwcOperator(Node):
     r"""
-    Creates a sparse piecewise-constant operator (sparse-matrix-valued function of time).
+    Create a sparse piecewise-constant operator (sparse-matrix-valued function of time).
 
     Each of the piecewise-constant segments (time periods) is a scalar multiple
     of the operator.
@@ -71,7 +72,7 @@ class SparsePwcOperator(Node):
     constant_sparse_pwc_operator : Create constant `SparsePwc`\s.
     density_matrix_evolution_pwc : Evolve a quantum state in an open system.
     pwc_operator : Corresponding operation for `Pwc`\s.
-    sparse_pwc_hermitian_part : Create the Hermitian part of a `SparsePwc` operator.
+    sparse_pwc_hermitian_part : Hermitian part of a `SparsePwc` operator.
     sparse_pwc_sum : Sum multiple `SparsePwc`\s.
     state_evolution_pwc : Evolve a quantum state.
 
@@ -112,10 +113,15 @@ class SparsePwcOperator(Node):
         batch_shape = signal.batch_shape
         check_argument(
             batch_shape == (),
-            "Batching is not supported for sparse_pwc.",
+            "Batching is not supported for SparsePwc nodes.",
             {"signal": signal},
             extras={"signal.batch_shape": batch_shape},
         )
+        check_argument(
+            isinstance(operator, (np.ndarray, spmatrix)),
+            "The operator must be a NumPy array or a SciPy sparse matrix.",
+            {"operator": operator},
+        )
         operator_shape = validate_shape(operator, "operator")
         check_argument(
             len(operator_shape) == 2 and operator_shape[0] == operator_shape[1],
@@ -123,12 +129,14 @@ class SparsePwcOperator(Node):
             {"operator": operator},
             extras={"operator.shape": operator_shape},
         )
-        return SparsePwc(_operation, value_shape=operator_shape)
+        return SparsePwc(
+            _operation, value_shape=operator_shape, durations=signal.durations
+        )
 
 
 class ConstantSparsePwcOperator(Node):
     r"""
-    Creates a constant sparse piecewise-constant operator over a specified duration.
+    Create a constant sparse piecewise-constant operator over a specified duration.
 
     Parameters
     ----------
@@ -146,7 +154,7 @@ class ConstantSparsePwcOperator(Node):
     See Also
     --------
     constant_pwc_operator : Corresponding operation for `Pwc`\s.
-    sparse_pwc_hermitian_part : Create the Hermitian part of a `SparsePwc` operator.
+    sparse_pwc_hermitian_part : Hermitian part of a `SparsePwc` operator.
     sparse_pwc_operator : Create `SparsePwc` operators.
     sparse_pwc_sum : Sum multiple `SparsePwc`\s.
 
@@ -178,6 +186,11 @@ class ConstantSparsePwcOperator(Node):
         duration = kwargs.get("duration")
         operator = kwargs.get("operator")
         check_duration(duration, "duration")
+        check_argument(
+            isinstance(operator, (np.ndarray, spmatrix)),
+            "The operator must be a NumPy array or a SciPy sparse matrix.",
+            {"operator": operator},
+        )
         operator_shape = validate_shape(operator, "operator")
         check_argument(
             len(operator_shape) == 2 and operator_shape[0] == operator_shape[1],
@@ -185,12 +198,14 @@ class ConstantSparsePwcOperator(Node):
             {"operator": operator},
             extras={"operator.shape": operator_shape},
         )
-        return SparsePwc(_operation, value_shape=operator_shape)
+        return SparsePwc(
+            _operation, value_shape=operator_shape, durations=np.array([duration])
+        )
 
 
 class SparsePwcSum(Node):
     r"""
-    Creates the sum of multiple sparse-matrix-valued piecewise-constant functions.
+    Create the sum of multiple sparse-matrix-valued piecewise-constant functions.
 
     Parameters
     ----------
@@ -245,7 +260,9 @@ class SparsePwcSum(Node):
             {"terms": terms},
             extras={"type(terms)": type(terms)},
         )
-
+        check_argument(
+            len(terms) > 0, "At least one term must be provided.", {"terms": terms}
+        )
         shape_0 = terms[0].value_shape
         for i in range(1, len(terms)):
             shape = terms[i].value_shape
@@ -258,12 +275,13 @@ class SparsePwcSum(Node):
                     f"terms[{i}].value_shape": shape,
                 },
             )
-        return SparsePwc(_operation, value_shape=shape_0)
+        durations = mesh_pwc_durations(terms)
+        return SparsePwc(_operation, value_shape=shape_0, durations=durations)
 
 
 class SparsePwcHermitianPart(Node):
     r"""
-    Creates the Hermitian part of a piecewise-constant operator.
+    Create the Hermitian part of a piecewise-constant operator.
 
     Parameters
     ----------
@@ -277,7 +295,7 @@ class SparsePwcHermitianPart(Node):
 
     See Also
     --------
-    hermitian_part : Create the Hermitian part of an operator.
+    hermitian_part : Hermitian part of an operator.
     sparse_pwc_operator : Create `SparsePwc`\s.
 
     Examples
@@ -305,12 +323,14 @@ class SparsePwcHermitianPart(Node):
             "The operator must be a SparsePwc.",
             {"operator": operator},
         )
-        return SparsePwc(_operation, value_shape=operator.value_shape)
+        return SparsePwc(
+            _operation, value_shape=operator.value_shape, durations=operator.durations
+        )
 
 
 class StateEvolutionPwc(Node):
     r"""
-    Calculates the time evolution of a state generated by a piecewise-constant
+    Calculate the time evolution of a state generated by a piecewise-constant
     Hamiltonian by using the Lanczos method.
 
     Parameters
@@ -358,11 +378,11 @@ class StateEvolutionPwc(Node):
     --------
     density_matrix_evolution_pwc : Corresponding operation for open systems.
     discretize_stf : Discretize an `Stf` into a `Pwc`.
-    estimated_krylov_subspace_dimension_lanczos : Obtain a Krylov subspace dimension to use
-        with this integrator.
+    estimated_krylov_subspace_dimension_lanczos :
+        Obtain a Krylov subspace dimension to use with this integrator.
     sparse_pwc_operator : Create `SparsePwc` operators.
-    time_evolution_operators_pwc : Unitary time evolution operators for quantum systems with
-        `Pwc` Hamiltonians.
+    time_evolution_operators_pwc :
+        Unitary time evolution operators for quantum systems with `Pwc` Hamiltonians.
 
     Notes
     -----
@@ -414,7 +434,9 @@ class StateEvolutionPwc(Node):
         sample_times = kwargs.get("sample_times")
         check_argument_numeric(initial_state, "initial_state")
         if sample_times is not None:
-            check_sample_times(sample_times, "sample_times")
+            check_sample_times_with_bounds(
+                sample_times, "sample_times", hamiltonian, "hamiltonian"
+            )
         check_argument(
             isinstance(hamiltonian, (SparsePwc, Pwc)),
             "The Hamiltonian must be a SparsePwc or a Pwc.",
@@ -447,7 +469,7 @@ class StateEvolutionPwc(Node):
 
 class EstimatedKrylovSubspaceDimensionLanczos(Node):
     r"""
-    Calculates an appropriate Krylov subspace dimension (:math:`k`) to use in the Lanczos
+    Calculate an appropriate Krylov subspace dimension (:math:`k`) to use in the Lanczos
     integrator while keeping the total error in the evolution below a given error tolerance.
 
     Note that you can provide your own estimation of the Hamiltonian spectral range or use the
@@ -565,7 +587,7 @@ class EstimatedKrylovSubspaceDimensionLanczos(Node):
 
 class SpectralRange(Node):
     r"""
-    Obtains the range of the eigenvalues of a Hermitian operator.
+    Obtain the range of the eigenvalues of a Hermitian operator.
 
     This function provides an estimate of the difference between the
     highest and the lowest eigenvalues of the operator. You can adjust its
