@@ -23,10 +23,6 @@ import forge
 import numpy as np
 
 from qctrlcommons.node.base import Node
-from qctrlcommons.node.deprecation import (
-    deprecated_node,
-    rename_parameter,
-)
 from qctrlcommons.node.documentation import Category
 from qctrlcommons.node.node_data import (
     ConvolutionKernel,
@@ -52,7 +48,7 @@ from qctrlcommons.preconditions import (
 
 class StfOperator(Node):
     r"""
-    Creates a constant operator multiplied by a sampleable signal.
+    Create a constant operator multiplied by a sampleable signal.
 
     Parameters
     ----------
@@ -73,6 +69,12 @@ class StfOperator(Node):
     constant_stf_operator : Create a constant `Stf` operator.
     pwc_operator : Corresponding operation for `Pwc`\s.
     stf_sum : Sum multiple `Stf`\s.
+
+    Notes
+    -----
+    For more information on `Stf` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
     """
 
     name = "stf_operator"
@@ -102,7 +104,7 @@ class StfOperator(Node):
 
 class ConstantStfOperator(Node):
     r"""
-    Creates a constant operator.
+    Create a constant operator.
 
     Parameters
     ----------
@@ -121,6 +123,12 @@ class ConstantStfOperator(Node):
     constant_pwc_operator : Corresponding operation for `Pwc`\s.
     constant_stf : Create a batch of constant `Stf`\s.
     stf_operator : Create an `Stf` operator.
+
+    Notes
+    -----
+    For more information on `Stf` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
     """
 
     name = "constant_stf_operator"
@@ -165,6 +173,12 @@ class ConstantStf(Node):
     constant_pwc : Corresponding operation for `Pwc`\s.
     constant_stf_operator : Create a constant sampleable function from operators.
     identity_stf : Create an `Stf` representing the identity function.
+
+    Notes
+    -----
+    For more information on `Stf` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
     """
 
     name = "constant_stf"
@@ -207,7 +221,7 @@ class ConstantStf(Node):
 
 class StfSum(Node):
     r"""
-    Creates the sum of multiple sampleable functions.
+    Create the sum of multiple sampleable functions.
 
     Parameters
     ----------
@@ -225,6 +239,12 @@ class StfSum(Node):
     hermitian_part : Hermitian part of an `Stf` operator.
     pwc_sum : Corresponding operation for `Pwc`\s.
     stf_operator : Create an `Stf` operator.
+
+    Notes
+    -----
+    For more information on `Stf` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
     """
 
     name = "stf_sum"
@@ -257,59 +277,9 @@ class StfSum(Node):
         return Stf(_operation, value_shape=value_shape, batch_shape=batch_shape)
 
 
-@deprecated_node(updated_node_name="hermitian_part")  # deprecated 2022/04/21
-class StfOperatorHermitianPart(Node):
-    r"""
-    Creates the Hermitian part of an operator-valued sampleable function.
-
-    Parameters
-    ----------
-    operator : Stf
-        The operator-valued sampleable function :math:`A(t)`.
-
-    Returns
-    -------
-    Stf
-        The Hermitian part of the Stf operator :math:`\frac{1}{2}(A(t) + A^\dagger(t))`.
-
-    See Also
-    --------
-    pwc_operator_hermitian_part : Corresponding operation for `Pwc`\s.
-    stf_operator : Create an `Stf` operator.
-
-    Examples
-    --------
-    >>> operator = stf_signal * np.array([[0, 1, 0], [0, 0, np.sqrt(2)], [0, 0, 0]])
-    >>> operator
-    <Stf: operation_name="multiply", value_shape=(3, 3), batch_shape=()>
-    >>> hamiltonian = graph.stf_operator_hermitian_part(operator)
-
-    Refer to the `How to perform model-based optimization with user-defined basis functions
-    <https://docs.q-ctrl.com/boulder-opal/user-guides/how-to-perform-model-based-optimization-with-user-defined-basis-functions>`_
-    user guide to find the example in context.
-    """
-
-    name = "stf_operator_hermitian_part"
-    args = [forge.arg("operator", type=Stf)]
-    kwargs = {}  # Stfs don't accept name as an argument.
-    rtype = Stf
-    categories = [Category.BUILDING_SMOOTH_HAMILTONIANS]
-
-    @classmethod
-    def create_node_data(cls, _operation, **kwargs):
-        operator = kwargs.get("operator")
-        check_argument(
-            isinstance(operator, Stf),
-            "The operator must be an Stf.",
-            {"operator": operator},
-        )
-        batch_shape, value_shape = validate_batch_and_value_shapes(operator, "operator")
-        return Stf(_operation, value_shape=value_shape, batch_shape=batch_shape)
-
-
 class DiscretizeStf(Node):
     r"""
-    Creates a piecewise-constant function by discretizing a sampleable function.
+    Create a piecewise-constant function by discretizing a sampleable function.
 
     Use this function to create a piecewise-constant approximation to a sampleable
     function (obtained, for example, by filtering an initial
@@ -365,6 +335,10 @@ class DiscretizeStf(Node):
         w_n = \frac{1}{M}
         \sum_{m=1}^M v\left(t_{n-1} + \left(m-\tfrac{1}{2}\right) \frac{\tau}{MN} \right).
 
+    For more information on `Stf` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
+
     Examples
     --------
     Create discretized Gaussian signal.
@@ -422,7 +396,7 @@ class DiscretizeStf(Node):
 
 class TimeEvolutionOperatorsStf(Node):
     """
-    Calculates the time-evolution operators for a system defined by an STF Hamiltonian by using a
+    Calculate the time-evolution operators for a system defined by an STF Hamiltonian by using a
     4th order Runge–Kutta method.
 
     Parameters
@@ -451,6 +425,12 @@ class TimeEvolutionOperatorsStf(Node):
     --------
     time_evolution_operators_pwc : Corresponding operation for `Pwc` Hamiltonians.
 
+    Notes
+    -----
+    For more information on `Stf` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
+
     Examples
     --------
     Simulate the dynamics of a qubit, where a simple Gaussian drive rotate the qubit
@@ -519,7 +499,7 @@ class TimeEvolutionOperatorsStf(Node):
 
 class ConvolvePwc(Node):
     r"""
-    Creates the convolution of a piecewise-constant function with a kernel.
+    Create the convolution of a piecewise-constant function with a kernel.
 
     Parameters
     ----------
@@ -536,6 +516,16 @@ class ConvolvePwc(Node):
         The sampleable function representing the signal :math:`(\alpha * K)(t)`
         (or batch of signals, if you provide a batch of functions).
 
+    See Also
+    --------
+    discretize_stf : Discretize an `Stf` into a `Pwc`.
+    gaussian_convolution_kernel : Create a convolution kernel representing a normalized Gaussian.
+    pwc : Create piecewise-constant functions.
+    sample_stf : Sample an `Stf` at given times.
+    sinc_convolution_kernel : Create a convolution kernel representing the sinc function.
+    :func:`.utils.filter_and_resample_pwc` :
+        Filter a `Pwc` with a sinc filter and resample it.
+
     Notes
     -----
     The convolution is
@@ -549,15 +539,9 @@ class ConvolvePwc(Node):
     time-invariant filter (specified via its time domain kernel :math:`K(t)`)
     to :math:`\alpha(t)`.
 
-    See Also
-    --------
-    discretize_stf : Discretize an `Stf` into a `Pwc`.
-    gaussian_convolution_kernel : Create a convolution kernel representing a normalized Gaussian.
-    pwc : Create piecewise-constant functions.
-    sample_stf : Sample an `Stf` at given times.
-    sinc_convolution_kernel : Create a convolution kernel representing the sinc function.
-    :func:`.utils.filter_and_resample_pwc` :
-        Filter a `Pwc` with a sinc filter and resample it.
+    For more information on `Stf` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
 
     Examples
     --------
@@ -590,12 +574,9 @@ class ConvolvePwc(Node):
         return Stf(_operation, value_shape=value_shape, batch_shape=batch_shape)
 
 
-@rename_parameter(  # deprecated 2022/04/11
-    old_name="cut_off_frequency", new_name="cutoff_frequency"
-)
 class SincConvolutionKernel(Node):
     r"""
-    Creates a convolution kernel representing the sinc function.
+    Create a convolution kernel representing the sinc function.
 
     Use this kernel to eliminate frequencies above a certain cutoff.
 
@@ -611,6 +592,13 @@ class SincConvolutionKernel(Node):
     ConvolutionKernel
         A node representing the sinc function to use in a convolution.
 
+    See Also
+    --------
+    convolve_pwc : Create an `Stf` by convolving a `Pwc` with a kernel.
+    gaussian_convolution_kernel : Create a convolution kernel representing a normalized Gaussian.
+    :func:`.utils.filter_and_resample_pwc` :
+        Filter a `Pwc` with a sinc filter and resample it.
+
     Notes
     -----
     The range of frequencies that this kernel lets pass is
@@ -624,12 +612,9 @@ class SincConvolutionKernel(Node):
     The function on the right side of the equation is the sinc function.
     Its integral is the sine integral function (Si).
 
-    See Also
-    --------
-    convolve_pwc : Create an `Stf` by convolving a `Pwc` with a kernel.
-    gaussian_convolution_kernel : Create a convolution kernel representing a normalized Gaussian.
-    :func:`.utils.filter_and_resample_pwc` :
-        Filter a `Pwc` with a sinc filter and resample it.
+    For more information on `Stf` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
 
     Examples
     --------
@@ -662,7 +647,7 @@ class SincConvolutionKernel(Node):
 
 class GaussianConvolutionKernel(Node):
     r"""
-    Creates a convolution kernel representing a normalized Gaussian.
+    Create a convolution kernel representing a normalized Gaussian.
 
     Use this kernel to allow frequencies in the range roughly determined by
     its width, and progressively suppress components outside that range.
@@ -682,6 +667,11 @@ class GaussianConvolutionKernel(Node):
     ConvolutionKernel
         A node representing a Gaussian function to use in a convolution.
 
+    See Also
+    --------
+    convolve_pwc : Create an `Stf` by convolving a `Pwc` with a kernel.
+    sinc_convolution_kernel : Create a convolution kernel representing the sinc function.
+
     Notes
     -----
     The Gaussian that this node represents is normalized in the time domain:
@@ -693,10 +683,9 @@ class GaussianConvolutionKernel(Node):
     :math:`\omega_c= \sigma^{-1}`. The filter it represents therefore
     passes frequencies roughly in the range :math:`[-\omega_c, \omega_c]`.
 
-    See Also
-    --------
-    convolve_pwc : Create an `Stf` by convolving a `Pwc` with a kernel.
-    sinc_convolution_kernel : Create a convolution kernel representing the sinc function.
+    For more information on `Stf` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
 
     Examples
     --------
@@ -732,7 +721,7 @@ class GaussianConvolutionKernel(Node):
 
 class SampleStf(Node):
     """
-    Samples an Stf at the given times.
+    Sample an Stf at the given times.
 
     Parameters
     ----------
@@ -755,6 +744,12 @@ class SampleStf(Node):
     discretize_stf : Discretize an `Stf` into a `Pwc`.
     identity_stf : Create an `Stf` representing the identity function.
     sample_pwc : Sample a `Pwc` at given times.
+
+    Notes
+    -----
+    For more information on `Stf` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
     """
 
     name = "sample_stf"
@@ -776,7 +771,7 @@ class SampleStf(Node):
 
 class IdentityStf(Node):
     r"""
-    Creates an Stf representing the identity function, f(t) = t.
+    Create an Stf representing the identity function, f(t) = t.
 
     Returns
     -------
@@ -789,6 +784,12 @@ class IdentityStf(Node):
     discretize_stf : Discretize an `Stf` into a `Pwc`.
     sample_stf : Sample an `Stf` at given times.
 
+    Notes
+    -----
+    For more information on `Stf` nodes see the `Working with time-dependent functions in
+    Boulder Opal <https://docs.q-ctrl.com/boulder-opal/topics/working-with-time-dependent-
+    functions-in-boulder-opal>`_ topic.
+
     Examples
     --------
     Create Gaussian pulse.
