@@ -42,7 +42,7 @@ from qctrlcommons.preconditions import (
 
 class RandomColoredNoiseStfSignal(Node):
     r"""
-    Samples the one-sided power spectral density (PSD) of a random noise process in the
+    Sample the one-sided power spectral density (PSD) of a random noise process in the
     time domain and returns the resultant noise trajectories as an `Stf`.
 
     Parameters
@@ -140,7 +140,7 @@ class RandomColoredNoiseStfSignal(Node):
 
 class RandomNormal(Node):
     r"""
-    Creates a sample of normally distributed random numbers.
+    Create a sample of normally distributed random numbers.
 
     Parameters
     ----------
@@ -164,8 +164,10 @@ class RandomNormal(Node):
 
     See Also
     --------
-    random_choices : Creates random samples from the data that you provide.
-    random_uniform : Creates a sample of uniformly distributed random numbers.
+    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_stochastic_optimization` :
+        Function to find the minimum of generic stochastic functions.
+    random_choices : Create random samples from the data that you provide.
+    random_uniform : Create a sample of uniformly distributed random numbers.
 
     Examples
     --------
@@ -248,7 +250,7 @@ class RandomNormal(Node):
 
 class RandomUniform(Node):
     r"""
-    Creates a sample of uniformly distributed random numbers.
+    Create a sample of uniformly distributed random numbers.
 
     Parameters
     ----------
@@ -272,8 +274,10 @@ class RandomUniform(Node):
 
     See Also
     --------
-    random_choices : Creates random samples from the data that you provide.
-    random_normal : Creates a sample of uniformly distributed random numbers.
+    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_stochastic_optimization` :
+        Function to find the minimum of generic stochastic functions.
+    random_choices : Create random samples from the data that you provide.
+    random_normal : Create a sample of uniformly distributed random numbers.
 
     Examples
     --------
@@ -329,7 +333,7 @@ class RandomUniform(Node):
 
 class RandomChoices(Node):
     r"""
-    Creates random samples from the data that you provide.
+    Create random samples from the data that you provide.
 
     You can provide the data as a list and each element of that list represents one component
     of the full data. For example, considering a single variable linear regression problem
@@ -372,8 +376,10 @@ class RandomChoices(Node):
 
     See Also
     --------
-    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_stochastic_optimization` : Function
-        to perform gradient-based stochastic optimization of generic real-valued functions.
+    :func:`~qctrl.dynamic.namespaces.FunctionNamespace.calculate_stochastic_optimization` :
+        Function to find the minimum of generic stochastic functions.
+    random_normal : Create a sample of uniformly distributed random numbers.
+    random_uniform : Create a sample of uniformly distributed random numbers.
 
     Examples
     --------
@@ -428,7 +434,10 @@ class RandomChoices(Node):
             check_argument_integer(seed, "seed")
 
         return_tensor_shapes = [(sample_count,) + value.shape[1:] for value in data]
-        node_constructor = lambda operation, index: Tensor(
-            operation, return_tensor_shapes[index]
+
+        return Sequence_(_operation).create_sequence(
+            node_constructor=lambda operation, index: Tensor(
+                operation, return_tensor_shapes[index]
+            ),
+            size=len(data),
         )
-        return Sequence_(_operation).create_sequence(node_constructor, size=len(data))
