@@ -52,7 +52,7 @@ from qctrlcommons.preconditions import (
 
 class TensorOperation(Node):
     """
-    Creates a real or complex Tensor with the data provided.
+    Create a real or complex Tensor with the data provided.
 
     Parameters
     ----------
@@ -87,7 +87,7 @@ class TensorOperation(Node):
 
 class Concatenate(Node):
     """
-    Concatenates a list of tensors along a specified dimension.
+    Concatenate a list of tensors along a specified dimension.
 
     Parameters
     ----------
@@ -145,6 +145,11 @@ class Concatenate(Node):
         tensors = kwargs.get("tensors")
         axis = kwargs.get("axis")
         check_argument_iterable(tensors, "tensors")
+        check_argument(
+            len(tensors) > 0,
+            "At least one tensor must be provided.",
+            {"tensors": tensors},
+        )
         tensor_shapes = []
         for index, tensor in enumerate(tensors):
             check_argument_numeric(tensor, f"tensors[{index}]")
@@ -169,7 +174,7 @@ class Concatenate(Node):
             )
         shape = (
             tensor_shapes[0][:axis]
-            + (sum([tensor_shape[axis] for tensor_shape in tensor_shapes]),)
+            + (sum(tensor_shape[axis] for tensor_shape in tensor_shapes),)
             + tensor_shapes[0][axis + 1 :]
         )
         return Tensor(_operation, shape=shape)
@@ -177,7 +182,7 @@ class Concatenate(Node):
 
 class Sum(Node):
     """
-    Sums the elements in a tensor (or a list of tensors with the same shape) along one or multiple
+    Sum the elements in a tensor (or a list of tensors with the same shape) along one or multiple
     of its axes.
 
     Parameters
@@ -297,7 +302,7 @@ class Sum(Node):
 
 class Reverse(Node):
     """
-    Reverses a tensor along some specified dimensions.
+    Reverse a tensor along some specified dimensions.
 
     Parameters
     ----------
@@ -351,7 +356,7 @@ class Reverse(Node):
 
 class Repeat(Node):
     """
-    Repeats elements of a tensor.
+    Repeat elements of a tensor.
 
     Parameters
     ----------
@@ -390,7 +395,7 @@ class Repeat(Node):
     >>> result.output["a"]["value"]
     array([1, 1, 2, 2, 3, 3])
 
-    Creates a new array with different repetitions for each element in the original array along its
+    Create a new array with different repetitions for each element in the original array along its
     second dimension.
 
     >>> graph.repeat(x, [2, 3, 4], axis=0, name="b")
@@ -408,7 +413,7 @@ class Repeat(Node):
     array([[1, 1, 2, 2, 3, 3],
            [4, 4, 5, 5, 6, 6]])
 
-    Creates a new array with different repetitions for each element in the original array along its
+    Create a new array with different repetitions for each element in the original array along its
     first dimension.
 
     >>> graph.repeat(y, [2, 3], axis=0, name="d")
@@ -467,7 +472,7 @@ class Repeat(Node):
 
 class CumulativeSum(Node):
     """
-    Calculates the cumulative sum of a tensor along a specified dimension.
+    Calculate the cumulative sum of a tensor along a specified dimension.
 
     Parameters
     ----------
@@ -535,7 +540,7 @@ class CumulativeSum(Node):
 
 class Transpose(Node):
     """
-    Reorders the dimensions of a tensor.
+    Reorder the dimensions of a tensor.
 
     Parameters
     ----------
@@ -592,7 +597,7 @@ class Transpose(Node):
 
 class PauliMatrix(Node):
     r"""
-    Creates a Pauli matrix from a label.
+    Create a Pauli matrix from a label.
 
     Parameters
     ----------
@@ -673,7 +678,7 @@ class PauliMatrix(Node):
 
 class PauliKroneckerProduct(Node):
     r"""
-    Places Pauli matrices into their two-dimensional subsystems of a system and
+    Place Pauli matrices into their two-dimensional subsystems of a system and
     returns the Kronecker product.
 
     Parameters
@@ -682,7 +687,7 @@ class PauliKroneckerProduct(Node):
         A list of tuples, each containing a pair of labels for the Pauli matrix and its position.
         The Pauli matrix label is a string ``'I'``, ``'X'``, ``'Y'``, ``'Z'``, ``'M'``, or ``'P'``
         and the position label is a non-negative integer and smaller than `system_count` indicating
-        the position of the Paul matrix in the system. At least one tuple must be provided.
+        the position of the Pauli matrix in the system. At least one tuple must be provided.
         ``'M'`` creates the lowering matrix :math:`\sigma_- = \frac{1}{2}(\sigma_x + i\sigma_y)`.
         ``'P'`` creates the raising matrix :math:`\sigma_+ = \frac{1}{2}(\sigma_x - i\sigma_y)`.
         We use the convention :math:`|\downarrow\rangle = \begin{bmatrix}1\\0\end{bmatrix}`
@@ -705,7 +710,7 @@ class PauliKroneckerProduct(Node):
 
     Examples
     --------
-    Places a single Pauli :math:`X` matrix in the second of two subsystems to create :math:`IX`.
+    Place a single Pauli :math:`X` matrix in the second of two subsystems to create :math:`IX`.
 
     >>> graph.pauli_kronecker_product([("X", 1)], subsystem_count=2, name="IX")
     <Tensor: name="IX", operation_name="pauli_kronecker_product", shape=(4, 4)>
@@ -716,7 +721,7 @@ class PauliKroneckerProduct(Node):
            [0.+0.j, 0.+0.j, 0.+0.j, 1.+0.j],
            [0.+0.j, 0.+0.j, 1.+0.j, 0.+0.j]])
 
-    Places a single Pauli :math:`X` matrix in the second of three subsystems to create :math:`IXI`.
+    Place a single Pauli :math:`X` matrix in the second of three subsystems to create :math:`IXI`.
 
     >>> graph.pauli_kronecker_product([("X", 1)], subsystem_count=3, name="IXI")
     <Tensor: name="IXI", operation_name="pauli_kronecker_product", shape=(8, 8)>
@@ -727,7 +732,7 @@ class PauliKroneckerProduct(Node):
            ...
            [0.+0.j, 0.+0.j, 0.+0.j, 0.+0.j, 0.+0.j, 1.+0.j, 0.+0.j, 0.+0.j]])
 
-    Places two Pauli :math:`X` matrices in the second and third of three subsystems
+    Place two Pauli :math:`X` matrices in the second and third of three subsystems
     to create :math:`IXX`.
 
     >>> graph.pauli_kronecker_product([("X", 1), ("X", 2)], subsystem_count=3, name="IXX")
@@ -795,7 +800,7 @@ class PauliKroneckerProduct(Node):
 
 class Einsum(Node):
     r"""
-    Performs tensor contraction via Einstein summation convention.
+    Perform tensor contraction via Einstein summation convention.
 
     Use this node to perform multi-dimensional, linear algebraic array operations between tensors.
 
@@ -994,7 +999,7 @@ class Einsum(Node):
 
 class ExpectationValue(Node):
     r"""
-    Calculates the expectation value of an operator with respect to a state.
+    Calculate the expectation value of an operator with respect to a state.
 
     The last dimension of the state must be equal to the last two dimensions
     of the operator and their batch shapes must be broadcastable.
@@ -1099,7 +1104,7 @@ class ExpectationValue(Node):
 
 class InnerProduct(Node):
     r"""
-    Calculates the inner product of two vectors.
+    Calculate the inner product of two vectors.
 
     The vectors must have the same last dimension and broadcastable shapes.
 
@@ -1180,7 +1185,7 @@ class InnerProduct(Node):
 
 class OuterProduct(Node):
     r"""
-    Calculates the outer product of two vectors.
+    Calculate the outer product of two vectors.
 
     The vectors can have different last dimensions but must have broadcastable batch dimensions.
 
@@ -1269,7 +1274,7 @@ class OuterProduct(Node):
 
 class PartialTrace(Node):
     r"""
-    Calculates the partial trace of a density matrix.
+    Calculate the partial trace of a density matrix.
 
     Parameters
     ----------
@@ -1406,7 +1411,7 @@ class PartialTrace(Node):
 
 class Reshape(Node):
     """
-    Reshapes a tensor into a new shape, keeping the order of its elements.
+    Reshape a tensor into a new shape, keeping the order of its elements.
 
     Parameters
     ----------
@@ -1479,7 +1484,7 @@ class Reshape(Node):
 
 class DensityMatrixInfidelity(Node):
     r"""
-    Calculates the infidelity between two states represented by density matrices.
+    Calculate the infidelity between two states represented by density matrices.
 
     Parameters
     ----------
@@ -1501,19 +1506,19 @@ class DensityMatrixInfidelity(Node):
         other. Its shape is the broadcasted value of the batch shapes of
         the two input parameters.
 
-    See Also
-    --------
-    infidelity_pwc : Total infidelity of a system with a piecewise-constant Hamiltonian.
-    infidelity_stf : Total infidelity of a system with a sampleable Hamiltonian.
-    state_infidelity : Infidelity between two quantum states.
-    unitary_infidelity : Calculates the infidelity between a unitary and target operators.
-
     Warnings
     --------
     This function assumes that the parameters are density matrices and
     therefore are positive definite. Passing matrices that have negative
     or complex eigenvalues will result in wrong values for the infidelity.
 
+    See Also
+    --------
+    infidelity_pwc : Total infidelity of a system with a piecewise-constant Hamiltonian.
+    infidelity_stf : Total infidelity of a system with a sampleable Hamiltonian.
+    state_infidelity : Infidelity between two quantum states.
+    unitary_infidelity : Infidelity between a unitary and target operators.
+
     Notes
     -----
     The general formula for the infidelity of two density matrices is
@@ -1565,7 +1570,7 @@ class DensityMatrixInfidelity(Node):
 
 class UnitaryInfidelity(Node):
     r"""
-    Calculates the infidelity between a target operation and the actual implemented unitary.
+    Calculate the infidelity between a target operation and the actual implemented unitary.
 
     Both operators must be square and have shapes broadcastable to each other.
 
@@ -1676,7 +1681,7 @@ class UnitaryInfidelity(Node):
 
 class StateInfidelity(Node):
     r"""
-    Calculates the infidelity of two pure states.
+    Calculate the infidelity of two pure states.
 
     Parameters
     ----------
@@ -1698,8 +1703,8 @@ class StateInfidelity(Node):
 
     See Also
     --------
-    inner_product : Calculate the inner product of two vectors.
-    unitary_infidelity : Calculates the infidelity between a unitary and target operators.
+    inner_product : Inner product of two vectors.
+    unitary_infidelity : Infidelity between a unitary and target operators.
 
     Notes
     -----
@@ -1751,7 +1756,7 @@ class StateInfidelity(Node):
 
 class EmbedOperators(Node):
     r"""
-    Embeds operators into a larger Hilbert space.
+    Embed operators into a larger Hilbert space.
 
     The size of the Hilbert space is defined by the dimensions argument.
 
@@ -1781,8 +1786,7 @@ class EmbedOperators(Node):
 
     Examples
     --------
-
-    Embedding a single operator.
+    Embed a single operator.
 
     >>> sigma_z = graph.pauli_matrix("Z")
     >>> graph.embed_operators((sigma_z, 0), [2, 3], name="Z0")
@@ -1798,7 +1802,7 @@ class EmbedOperators(Node):
            [ 0.+0.j,  0.+0.j,  0.+0.j,  0.+0.j, -1.+0.j,  0.+0.j],
            [ 0.+0.j,  0.+0.j,  0.+0.j,  0.+0.j,  0.+0.j, -1.+0.j]])
 
-    Embedding multiple operators.
+    Embed multiple operators.
 
     >>> number_op = graph.number_operator(2)
     >>> sigma_x = graph.pauli_matrix("X")
@@ -1873,7 +1877,7 @@ class EmbedOperators(Node):
 
 class KroneckerProductList(Node):
     r"""
-    Calculates the Kronecker product between a list of operators.
+    Calculate the Kronecker product between a list of operators.
 
     Parameters
     ----------
@@ -1897,7 +1901,6 @@ class KroneckerProductList(Node):
 
     Examples
     --------
-
     >>> number_op = graph.number_operator(3)
     >>> sigma_x = graph.pauli_matrix("X")
     >>> graph.kronecker_product_list([number_op, sigma_x], name="N0X1")
@@ -1954,7 +1957,7 @@ class KroneckerProductList(Node):
 
 class Min(Node):
     """
-    Finds the minimum value in a tensor along one or multiple of its axes.
+    Find the minimum value in a tensor along one or multiple of its axes.
 
     Parameters
     ----------
@@ -1978,7 +1981,7 @@ class Min(Node):
 
     See Also
     --------
-    max : Finds the maximum value in a tensor along one or multiple of its axes.
+    max : Find the maximum value in a tensor along one or multiple of its axes.
     """
 
     name = "min"
@@ -2009,7 +2012,7 @@ class Min(Node):
 
 class Max(Node):
     """
-    Finds the maximum value in a tensor along one or multiple of its axes.
+    Find the maximum value in a tensor along one or multiple of its axes.
 
     Parameters
     ----------
@@ -2033,7 +2036,7 @@ class Max(Node):
 
     See Also
     --------
-    min : Finds the minimum value in a tensor along one or multiple of its axes.
+    min : Find the minimum value in a tensor along one or multiple of its axes.
     """
 
     name = "max"
