@@ -42,7 +42,7 @@ _IntType = (int, np.integer)
 
 def get_broadcasted_shape(*shapes):
     """
-    Returns the shape resulting of broadcasting multiple shapes,
+    Return the shape resulting of broadcasting multiple shapes,
     or None if they're not broadcastable.
 
     The shapes are broadcastable if, for each dimension starting from the end,
@@ -60,7 +60,7 @@ def get_broadcasted_shape(*shapes):
     """
 
     # Obtain largest length of shapes.
-    max_shape_len = max([len(shape) for shape in shapes])
+    max_shape_len = max(len(shape) for shape in shapes)
 
     # Prepend ones to shorter shapes.
     extended_shapes = [(1,) * (max_shape_len - len(shape)) + shape for shape in shapes]
@@ -80,7 +80,7 @@ def get_broadcasted_shape(*shapes):
 
 def validate_broadcasted_shape(x_shape, y_shape, x_name, y_name):
     """
-    Gets the resulting broadcasted shape for two input shapes,
+    Get the resulting broadcasted shape for two input shapes,
     throwing an error if they're not broadcastable.
 
     Parameters
@@ -120,7 +120,7 @@ def validate_function_output_shapes(
     x_batch_shape, x_value_shape, y_batch_shape, y_value_shape, validate_value_shape
 ):
     """
-    Gets the output batch and value shape for two input shapes of Pwcs/Stfs.
+    Get the output batch and value shape for two input shapes of Pwcs/Stfs.
     The names of the variables are assumed to be x and y when reporting errors.
 
     Parameters
@@ -169,7 +169,7 @@ def validate_tensor_and_function_output_shapes(
     tensor_first=True,
 ):
     """
-    Gets the output batch and value shape for an input tensor and an input Pwc/Stf.
+    Get the output batch and value shape for an input tensor and an input Pwc/Stf.
 
     Parameters
     ----------
@@ -215,7 +215,7 @@ def validate_tensor_and_function_output_shapes(
 
 def validate_shape(tensor_like, tensor_like_name):
     """
-    Returns the shape of a scalar, np.ndarray, scipy.sparse.spmatrix, or Tensor node.
+    Return the shape of a scalar, np.ndarray, scipy.sparse.spmatrix, or Tensor node.
 
     Parameters
     ----------
@@ -247,7 +247,7 @@ def validate_shape(tensor_like, tensor_like_name):
 
 def validate_batch_and_value_shapes(tensor, tensor_name):
     """
-    Returns the batch and value shapes of Pwc or Stf.
+    Return the batch and value shapes of Pwc or Stf.
 
     Parameters
     ----------
@@ -281,7 +281,7 @@ def validate_batch_and_value_shapes(tensor, tensor_name):
 
 def validate_hamiltonian(hamiltonian, hamiltonian_name):
     """
-    Checks whether a Pwc, Stf or SparsePwc contains values that are Hamiltonians.
+    Check whether a Pwc, Stf or SparsePwc contains values that are Hamiltonians.
 
     Hamiltonians are two-dimensional and square.
 
@@ -310,7 +310,7 @@ def validate_hamiltonian(hamiltonian, hamiltonian_name):
 
 def validate_ms_shapes(ion_count, ld_values, ld_name, rd_values, rd_name):
     """
-    Checks if the shapes of the Mølmer–Sørensen parameters are correct.
+    Check if the shapes of the Mølmer–Sørensen parameters are correct.
 
     The correct shapes for the input parameters of Mølmer–Sørensen gate are
     ``(3, ion_count, ion_count)`` for the Lamb–Dicke parameters and
@@ -351,7 +351,7 @@ def validate_ms_shapes(ion_count, ld_values, ld_name, rd_values, rd_name):
 
 def validate_batched_operator(operator, name):
     """
-    Checks if the input is a valid batched operator.
+    Check if the input is a valid batched operator.
 
     Parameters
     ----------
@@ -388,7 +388,7 @@ def validate_batched_operator(operator, name):
 
 def check_density_matrix_shape(density_matrix, name):
     """
-    Checks the shape of the input density matrix.
+    Check the shape of the input density matrix.
 
     Parameters
     ----------
@@ -408,7 +408,7 @@ def check_density_matrix_shape(density_matrix, name):
 
 def check_oqs_hamiltonian(hamiltonian, initial_density_matrix):
     """
-    Check whether open quantum system (OQS) Hamiltonian is valid.
+    Check whether an open quantum system (OQS) Hamiltonian is valid.
 
     Parameters
     ----------
@@ -640,8 +640,8 @@ def validate_field_operator_input(parameter, lower_bound, name):
 
 def validate_coherent_state_alpha(alpha):
     """
-    Check whether alpha is valid for generating coherent state.
-    Returns the batch shape if alpha is valid. Otherwise, raise an error.
+    Check whether alpha is valid for generating coherent state and
+    return the batch shape if alpha is valid. Otherwise, raise an error.
     """
 
     if isinstance(alpha, list):
@@ -754,7 +754,7 @@ def check_operation_axis(axis, shape, tensor, tensor_name):
 
 def get_keepdims_operation_shape(shape, axis, keepdims):
     """
-    Returns the shape of the operations that can keep the dimension of the input tensor.
+    Return the shape of the operations that can keep the dimension of the input tensor.
     """
     output_shape = []
     for i, size in enumerate(shape):
@@ -763,3 +763,23 @@ def get_keepdims_operation_shape(shape, axis, keepdims):
         elif keepdims:
             output_shape.append(1)
     return tuple(output_shape)
+
+
+def mesh_pwc_durations(pwcs):
+    """
+    Return an array with the durations resulting of meshing the durations
+    of the input PWC functions.
+
+    Parameters
+    ----------
+    pwcs : list[Pwc or SparsePwc]
+        The PWC functions whose durations should be meshed.
+
+    Returns
+    -------
+    np.array
+        The array with meshed durations.
+    """
+
+    times = np.unique(np.concatenate([np.cumsum(pwc.durations) for pwc in pwcs]))
+    return np.diff(np.insert(times, 0, 0))
