@@ -389,6 +389,34 @@ def check_sample_times(sample_times, sample_times_name):
     )
 
 
+def check_sample_times_with_bounds(sample_times, sample_times_name, pwc, pwc_name):
+    """
+    Checks that the sample_times array is valid (see check_sample_times) and
+    that its values lie between 0 and sum(pwc.durations) (included).
+
+    Parameters
+    ----------
+    sample_times : np.ndarray
+        The array to be tested.
+    sample_times_name : str
+        The name of the array.
+    pwc : Union[Pwc, SparsePwc]
+        The PWC function whose duration bounds the values of the sample times.
+    pwc_name : str
+        The name of the PWC function.
+    """
+    check_sample_times(sample_times, sample_times_name)
+
+    duration = np.sum(pwc.durations)
+    check_argument(
+        (sample_times[0] >= 0.0 or np.isclose(sample_times[0], 0.0))
+        and (sample_times[-1] <= duration or np.isclose(sample_times[-1], duration)),
+        f"{sample_times_name} must be between 0 and the duration of {pwc_name}.",
+        {sample_times_name: sample_times, pwc_name: pwc},
+        extras={"sum({duration_pwc_name}.durations)": duration},
+    )
+
+
 def check_operator(operator, operator_name):
     """
     Checks that the operator is a square 2D array or tensor, or a batch of them.
