@@ -25,7 +25,10 @@ def _check_cross_entropy_initializer(input_):
     """
     Checks input parameters for the cross entropy optimizer.
     """
-    elite_fraction = input_["optimizer"]["crossEntropyInitializer"]["eliteFraction"]
+    initializer = input_["optimizer"]["crossEntropyInitializer"]
+    elite_fraction = initializer["eliteFraction"]
+
+    _check_seed(initializer.get("rngSeed"))
 
     if elite_fraction <= 0 or elite_fraction >= 1:
         raise QctrlFieldError(
@@ -43,6 +46,11 @@ def _check_cross_entropy_initializer(input_):
             fields=["results"],
         )
 
+    bounds = initializer.get("bounds")
+    if bounds is not None:
+        parameter_count = len(results[0]["parameters"])
+        _check_parameter_bounds(bounds, parameter_count)
+
 
 def _check_box_constraint(constraint, field):
     """
@@ -92,6 +100,7 @@ def _check_gaussian_process_initializer(input_):
     bounds = initializer["bounds"]
     parameter_count = len(input_["results"][0]["parameters"])
     _check_parameter_bounds(bounds, parameter_count)
+    _check_seed(initializer.get("rngSeed"))
 
     length_scale_bounds = initializer.get("lengthScaleBounds")
     if length_scale_bounds is not None:
@@ -120,6 +129,7 @@ def _check_simulated_annealing_initializer(input_):
     bounds = initializer["bounds"]
     parameter_count = len(input_["results"][0]["parameters"])
     _check_parameter_bounds(bounds, parameter_count)
+    _check_seed(initializer.get("rngSeed"))
 
     temperatures = initializer["temperatures"]
     if len(temperatures) != parameter_count:
@@ -150,6 +160,54 @@ def _check_neural_network_initializer(input_):
     parameter_count = len(input_["results"][0]["parameters"])
 
     _check_parameter_bounds(bounds, parameter_count)
+    _check_seed(initializer.get("rngSeed"))
+
+
+def _check_cmaes_initializer(input_):
+    """
+    Checks input parameters for the CMA-ES optimizer.
+    """
+    initializer = input_["optimizer"]["cmaesInitializer"]
+    bounds = initializer["bounds"]
+    parameter_count = len(input_["results"][0]["parameters"])
+
+    _check_parameter_bounds(bounds, parameter_count)
+    _check_seed(initializer.get("rngSeed"))
+
+    initial_mean = initializer.get("initialMean")
+    initial_cov = initializer.get("initialCovariance")
+
+    if initial_cov is not None:
+        if len(initial_cov) != parameter_count:
+            raise QctrlFieldError(
+                message="The number of rows in the initial covariance must be the same as "
+                "the number of parameters.",
+                fields=["initialCovariance"],
+            )
+        for row in initial_cov:
+            if len(row) != parameter_count:
+                raise QctrlFieldError(
+                    message="The length of each element in the initial covariance must be the "
+                    "same as the number of parameters.",
+                    fields=["initialCovariance"],
+                )
+
+    if initial_mean is not None:
+        if len(initial_mean) != parameter_count:
+            raise QctrlFieldError(
+                message="The length of initial mean must be the same as the number of parameters.",
+                fields=["initialMean"],
+            )
+
+    results = input_.get("results")
+    min_result_count = 4 + int(np.floor(3 * np.log(parameter_count)))
+    if results is None or len(results) < min_result_count:
+        raise QctrlFieldError(
+            message=Messages(
+                field_name="results", minimum=min_result_count, items="items"
+            ).min_items,
+            fields=["results"],
+        )
 
 
 AVAILABLE_OPTIMIZERS = {
@@ -157,9 +215,18 @@ AVAILABLE_OPTIMIZERS = {
     "gaussianProcessInitializer": _check_gaussian_process_initializer,
     "neuralNetworkInitializer": _check_neural_network_initializer,
     "simulatedAnnealingInitializer": _check_simulated_annealing_initializer,
+    "cmaesInitializer": _check_cmaes_initializer,
 }
 
 
+def _check_seed(seed):
+    if seed is not None and seed < 0:
+        raise QctrlFieldError(
+            message="Ensure seed value is greater than or equal to 0.",
+            fields=["seed"],
+        )
+
+
 class CalculateClosedLoopOptimizationStepValidator(BaseMutationInputValidator):
     """
     Validator for core__calculateClosedLoopOptimizationStep mutation.
