@@ -25,7 +25,10 @@ class CalculateOptimizationValidator(BaseMutationInputValidator):
     Validator for core__calculateOptimization mutation.
     """
 
-    properties = {"optimizationCount": {"type": "number", "exclusiveMinimum": 0}}
+    properties = {
+        "optimizationCount": {"type": "number", "exclusiveMinimum": 0},
+        "seed": {"type": "number", "minimum": 0},
+    }
 
     def check_cost_in_graph(self, input_: dict):  # pylint:disable=no-self-use
         """Expect the cost node to be in the graph.
