@@ -40,7 +40,10 @@ class CalculateStochasticOptimizationValidator(BaseMutationInputValidator):
     Validator for core__calculateStochasticOptimization mutation.
     """
 
-    properties = {"iterationCount": {"type": "number", "exclusiveMinimum": 0}}
+    properties = {
+        "iterationCount": {"type": "number", "exclusiveMinimum": 0},
+        "seed": {"type": "number", "minimum": 0},
+    }
 
     def check_cost_in_graph(self, _input):  # pylint:disable=no-self-use
         """
